/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedRepositoriesAsResponse } from "../definitions/PaginatedRepositoriesAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ErrorAsResponse } from "../definitions/ErrorAsResponse";
import { RepositoryAsResponse } from "../definitions/RepositoryAsResponse";
import { PaginatedRefsAsResponse } from "../definitions/PaginatedRefsAsResponse";
export interface GetRepositoriesRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * Filter the results to include only repositories created on or
  after this [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601)
   timestamp. Example: `YYYY-MM-DDTHH:mm:ss.sssZ`
  */
    after?: string;
    /**
  * Filters the result based on the authenticated user's role on each repository.
  
  * **member**: returns repositories to which the user has explicit read access
  * **contributor**: returns repositories to which the user has explicit write access
  * **admin**: returns repositories to which the user has explicit administrator access
  * **owner**: returns all repositories owned by the current user
  
  */
    role?: "admin" | "contributor" | "member" | "owner";
    /**
  * Query string to narrow down the response as per [filtering and sorting](../meta/filtering).
  `role` parameter must also be specified.
   Example:`language="javascript"`
  */
    q?: string;
    /**
  * Field by which the results should be sorted as per [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
  
  */
    sort?: string;
}
declare type GetRepositoriesResponseOKType = PaginatedRepositoriesAsResponse;
export interface GetRepositoriesResponseOK extends GetRepositoriesResponseOKType {
}
export declare type GetRepositoriesResponseError = undefined;
export interface GetRepositoriesByWorkspaceRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
  *
  Filters the result based on the authenticated user's role on each repository.
  
  * **member**: returns repositories to which the user has explicit read access
  * **contributor**: returns repositories to which the user has explicit write access
  * **admin**: returns repositories to which the user has explicit administrator access
  * **owner**: returns all repositories owned by the current user
  
  */
    role?: "admin" | "contributor" | "member" | "owner";
    /**
  *
  Query string to narrow down the response as per [filtering and sorting](../../meta/filtering).
   Example:`language="javascript"`
  */
    q?: string;
    /**
  *
  Field by which the results should be sorted as per [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
          
  */
    sort?: string;
}
declare type GetRepositoriesByWorkspaceResponseOKType = PaginatedRepositoriesAsResponse;
export interface GetRepositoriesByWorkspaceResponseOK extends GetRepositoriesByWorkspaceResponseOKType {
}
declare type GetRepositoriesByWorkspaceResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoriesByWorkspaceResponseError extends GetRepositoriesByWorkspaceResponseErrorType {
}
export interface GetRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetRepositoryResponseOKType = RepositoryAsResponse;
export interface GetRepositoryResponseOK extends GetRepositoryResponseOKType {
}
declare type GetRepositoryResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoryResponseError extends GetRepositoryResponseErrorType {
}
export interface UpdateRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       * Note: When creating a new project, this must be a slug. Slugs must be lowercase, alphanumerical, and may also contain underscores, dashes, or dots.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body: {
        /**
         * Note: Specifying the project parameter will always result in attempting to create a new project rather than update an existing one.
         */
        project?: {
            key: string;
        };
        /**
             * Note: Changing the name of the repository will cause the location to be changed.
             This is because the URL of the repo is derived from the name (a process called slugification).
             In such a scenario, it is possible for the request to fail if the newly created slug conflicts with an existing repository's slug.
             But if there is no conflict, the new location will be returned in the Location header of the response.
             */
        name?: string;
        description?: string;
        language?: string;
        website?: string;
        has_issues?: boolean;
        has_wiki?: boolean;
        /**
         * Note: When updating a project, specifying the is_private parameter can throw an error.
         */
        is_private?: boolean;
        /**
         * Note: When updating a project, specifying the fork_policy parameter does not have the desired effect and can give unexpected results.
         */
        fork_policy?: "allow_forks" | "no_public_forks" | "no_forks";
    };
}
export interface UpdateRepositoryResponseOK extends RepositoryAsResponse {
}
export interface UpdateRepositoryResponseError extends ErrorAsResponse {
}
export interface CreateRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Slugs must be lowercase, alphanumerical, and may also contain underscores, dashes, or dots.
     */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body: {
        /**
         * The project must be assigned for all repositories. If the project is not provided, the repository is automatically assigned to the oldest project in the workspace.
         * If there are no projects present in the workspace, a default one will automatically be created.
         */
        project?: {
            key: string;
        };
        name?: string;
        description?: string;
        language?: string;
        website?: string;
        has_issues?: boolean;
        has_wiki?: boolean;
        is_private?: boolean;
        fork_policy?: "allow_forks" | "no_public_forks" | "no_forks";
    };
}
export interface CreateRepositoryResponseOK extends RepositoryAsResponse {
}
export interface CreateRepositoryResponseError extends ErrorAsResponse {
}
export interface DeleteRepositoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
  * If a repository has been moved to a new location, use this parameter to
  show users a friendly message in the Bitbucket UI that the repository
  has moved to a new location. However, a GET to this endpoint will still
  return a 404.
  
  */
    redirect_to?: string;
}
export declare type DeleteRepositoryResponseOK = undefined;
declare type DeleteRepositoryResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface DeleteRepositoryResponseError extends DeleteRepositoryResponseErrorType {
}
export interface GetRepositoryBranchesAndTagsRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
  *
  Query string to narrow down the response as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
   Example:`target.hash="1e9e09996d3f636c7254942bdaf15c4fcd4f0fd4"`
  */
    q?: string;
    /**
  *
  Field by which the results should be sorted as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering). The `name`
  field is handled specially for refs in that, if specified as the sort field, it
  uses a natural sort order instead of the default lexicographical sort order. For example,
  it will return ['1.1', '1.2', '1.10'] instead of ['1.1', '1.10', '1.2'].
  */
    sort?: string;
}
declare type GetRepositoryBranchesAndTagsResponseOKType = PaginatedRefsAsResponse;
export interface GetRepositoryBranchesAndTagsResponseOK extends GetRepositoryBranchesAndTagsResponseOKType {
}
declare type GetRepositoryBranchesAndTagsResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoryBranchesAndTagsResponseError extends GetRepositoryBranchesAndTagsResponseErrorType {
}
export {};
//# sourceMappingURL=repository.d.ts.map