/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { URLEncodeBodyWithDuplicateValues } from "./common";
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class BitbucketCloudApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Repository = new RepositoryGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.User = new UserGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Workspace = new WorkspaceGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Repository, this.User, this.Workspace);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Repository, User, Workspace) {
        this.Repository = Repository;
        this.User = User;
        this.Workspace = Workspace;
    }
    /**
  * Returns a paginated list of all public repositories.
  
  This endpoint also supports filtering and sorting of the results. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering) for more details.
  * Alternative usage: Repository.getRepositories
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-get
  * @param options Request options.
  */
    async getRepositories(options) {
        return this.Repository.getRepositories(options);
    }
    /**
  * Returns a paginated list of all repositories owned by the specified
  workspace.
  
  The result can be narrowed down based on the authenticated user's role.
  
  E.g. with `?role=contributor`, only those repositories that the
  authenticated user has write access to are returned (this includes any
  repo the user is an admin on, as that implies write access).
  
  This endpoint also supports filtering and sorting of the results. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering) for more details.
  * Alternative usage: Repository.getRepositoriesByWorkspace
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-get
  * @param options Request options.
  */
    async getRepositoriesByWorkspace(options) {
        return this.Repository.getRepositoriesByWorkspace(options);
    }
    /**
     * Returns the object describing this repository.
     * Alternative usage: Repository.getRepository
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-get
     * @param options Request options.
     */
    async getRepository(options) {
        return this.Repository.getRepository(options);
    }
    /**
  * Since this endpoint can be used to both update and to create a
  repository, the request body depends on the intent.
  
  #### Creation
  
  See the POST documentation for the repository endpoint for an example
  of the request body.
  
  #### Update
  
  Note: Changing the `name` of the repository will cause the location to
  be changed. This is because the URL of the repo is derived from the
  name (a process called slugification). In such a scenario, it is
  possible for the request to fail if the newly created slug conflicts
  with an existing repository's slug. But if there is no conflict,
  the new location will be returned in the `Location` header of the
  response.
  * Alternative usage: Repository.updateRepository
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-put
  * @param options Request options.
  */
    async updateRepository(options) {
        return this.Repository.updateRepository(options);
    }
    /**
  * Creates a new repository.
  
  Note: In order to set the project for the newly created repository,
  pass in either the project key or the project UUID as part of the
  request body as shown in the examples below:
  
  ```
  $ curl -X POST -H "Content-Type: application/json" -d '{
      "scm": "git",
      "project": {
          "key": "MARS"
      }
  }' https://api.bitbucket.org/2.0/repositories/teamsinspace/hablanding
  ```
  
  or
  
  ```
  $ curl -X POST -H "Content-Type: application/json" -d '{
      "scm": "git",
      "project": {
          "key": "{ba516952-992a-4c2d-acbd-17d502922f96}"
      }
  }' https://api.bitbucket.org/2.0/repositories/teamsinspace/hablanding
  ```
  
  The project must be assigned for all repositories. If the project is not provided,
  the repository is automatically assigned to the oldest project in the workspace.
  
  Note: In the examples above, the workspace ID `teamsinspace`,
  and/or the repository name `hablanding` can be replaced by UUIDs.
  * Alternative usage: Repository.createRepository
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-post
  * @param options Request options.
  */
    async createRepository(options) {
        return this.Repository.createRepository(options);
    }
    /**
  * Deletes the repository. This is an irreversible operation.
  
  This does not affect its forks.
  * Alternative usage: Repository.deleteRepository
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-delete
  * @param options Request options.
  */
    async deleteRepository(options) {
        return this.Repository.deleteRepository(options);
    }
    /**
  * Returns the branches and tags in the repository.
  
  By default, results will be in the order the underlying source control system returns them and identical to
  the ordering one sees when running "$ git show-ref". Note that this follows simple
  lexical ordering of the ref names.
  
  This can be undesirable as it does apply any natural sorting semantics, meaning for instance that refs are
  sorted ["branch1", "branch10", "branch2", "v10", "v11", "v9"] instead of ["branch1", "branch2",
  "branch10", "v9", "v10", "v11"].
  
  Sorting can be changed using the ?sort= query parameter. When using ?sort=name to explicitly sort on ref name,
  Bitbucket will apply natural sorting and interpret numerical values as numbers instead of strings.
  * Alternative usage: Repository.getBranchesAndTags
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-get
  * @param options Request options.
  */
    async getRepositoryBranchesAndTags(options) {
        return this.Repository.getBranchesAndTags(options);
    }
    /**
  * Endpoint to create and initiate a pipeline.
  There are a couple of different options to initiate a pipeline, where the payload of the request will determine which type of pipeline will be instantiated.
  # Trigger a Pipeline for a branch
  One way to trigger pipelines is by specifying the branch for which you want to trigger a pipeline.
  The specified branch will be used to determine which pipeline definition from the `bitbucket-pipelines.yml` file will be applied to initiate the pipeline. The pipeline will then do a clone of the repository and checkout the latest revision of the specified branch.
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/jeroendr/meat-demo2/pipelines/ \
    -d '
    {
      "target": {
        "ref_type": "branch",
        "type": "pipeline_ref_target",
        "ref_name": "master"
      }
    }'
  ```
  # Trigger a Pipeline for a commit on a branch or tag
  You can initiate a pipeline for a specific commit and in the context of a specified reference (e.g. a branch, tag or bookmark).
  The specified reference will be used to determine which pipeline definition from the bitbucket-pipelines.yml file will be applied to initiate the pipeline. The pipeline will clone the repository and then do a checkout the specified reference.
  
  The following reference types are supported:
  
  * `branch`
  * `named_branch`
  * `bookmark`
   * `tag`
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
    https://api.bitbucket.org/2.0/repositories/jeroendr/meat-demo2/pipelines/ \
    -d '
    {
      "target": {
        "commit": {
          "type": "commit",
          "hash": "ce5b7431602f7cbba007062eeb55225c6e18e956"
        },
        "ref_type": "branch",
        "type": "pipeline_ref_target",
        "ref_name": "master"
      }
    }'
  ```
  # Trigger a specific pipeline definition for a commit
  You can trigger a specific pipeline that is defined in your `bitbucket-pipelines.yml` file for a specific commit.
  In addition to the commit revision, you specify the type and pattern of the selector that identifies the pipeline definition. The resulting pipeline will then clone the repository and checkout the specified revision.
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/jeroendr/meat-demo2/pipelines/ \
   -d '
    {
       "target": {
        "commit": {
           "hash":"a3c4e02c9a3755eccdc3764e6ea13facdf30f923",
           "type":"commit"
         },
          "selector": {
             "type":"custom",
                "pattern":"Deploy to production"
            },
          "type":"pipeline_commit_target"
     }
    }'
  ```
  # Trigger a specific pipeline definition for a commit on a branch or tag
  You can trigger a specific pipeline that is defined in your `bitbucket-pipelines.yml` file for a specific commit in the context of a specified reference.
  In addition to the commit revision, you specify the type and pattern of the selector that identifies the pipeline definition, as well as the reference information. The resulting pipeline will then clone the repository a checkout the specified reference.
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/jeroendr/meat-demo2/pipelines/ \
   -d '
    {
       "target": {
        "commit": {
           "hash":"a3c4e02c9a3755eccdc3764e6ea13facdf30f923",
           "type":"commit"
         },
         "selector": {
            "type": "custom",
            "pattern": "Deploy to production"
         },
         "type": "pipeline_ref_target",
         "ref_name": "master",
         "ref_type": "branch"
       }
    }'
  ```
  
  
  # Trigger a custom pipeline with variables
  In addition to triggering a custom pipeline that is defined in your `bitbucket-pipelines.yml` file as shown in the examples above, you can specify variables that will be available for your build. In the request, provide a list of variables, specifying the following for each variable: key, value, and whether it should be secured or not (this field is optional and defaults to not secured).
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/{workspace}/{repo_slug}/pipelines/ \
   -d '
    {
      "target": {
        "type": "pipeline_ref_target",
        "ref_type": "branch",
        "ref_name": "master",
        "selector": {
          "type": "custom",
          "pattern": "Deploy to production"
        }
      },
      "variables": [
        {
          "key": "var1key",
          "value": "var1value",
          "secured": true
        },
        {
          "key": "var2key",
          "value": "var2value"
        }
      ]
    }'
  ```
  
  # Trigger a pull request pipeline
  
  You can also initiate a pipeline for a specific pull request.
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/{workspace}/{repo_slug}/pipelines/ \
   -d '
    {
      "target": {
        "type": "pipeline_pullrequest_target",
        "source": "pull-request-branch",
        "destination": "master",
        "destination_commit": {
          "hash": "9f848b7"
        },
        "commit": {
          "hash": "1a372fc"
        },
        "pullrequest": {
          "id": "3"
        },
        "selector": {
          "type": "pull-requests",
          "pattern": "**"
        }
      }
    }'
  ```
    
  * Alternative usage: Repository.Pipeline.createAndInitiatePipeline
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-post
  * @param options Request options.
  */
    async createAndInitiateRepositoryPipeline(options) {
        return this.Repository.Pipeline.createAndInitiatePipeline(options);
    }
    /**
  * Find pipelines in a repository.
  
  Note that unlike other endpoints in the Bitbucket API, this endpoint utilizes query parameters to allow filtering
  and sorting of returned results. See [query parameters](#api-repositories-workspace-repo-slug-pipelines-get-request-Query%20parameters)
  for specific details.
    
  * Alternative usage: Repository.Pipeline.findPipelines
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-get
  * @param options Request options.
  */
    async findRepositoryPipelines(options) {
        return this.Repository.Pipeline.findPipelines(options);
    }
    /**
     * Retrieve a specified pipeline
     * Alternative usage: Repository.Pipeline.retrievePipeline
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-get
     * @param options Request options.
     */
    async retrieveRepositoryPipeline(options) {
        return this.Repository.Pipeline.retrievePipeline(options);
    }
    /**
     * Signal the stop of a pipeline and all of its steps that not have completed yet.
     * Alternative usage: Repository.Pipeline.stopPipeline
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-pipeline-uuid-stoppipeline-post
     * @param options Request options.
     */
    async stopRepositoryPipeline(options) {
        return this.Repository.Pipeline.stopPipeline(options);
    }
    /**
     * Find steps for the given pipeline.
     * Alternative usage: Repository.Pipeline.Step.findSteps
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-pipeline-uuid-steps-get
     * @param options Request options.
     */
    async findRepositoryStepsForPipeline(options) {
        return this.Repository.Pipeline.Step.findSteps(options);
    }
    /**
     * Retrieve a given step of a pipeline.
     * Alternative usage: Repository.Pipeline.Step.retrieveStep
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-pipeline-uuid-steps-step-uuid-get
     * @param options Request options.
     */
    async retrieveRepositoryStepForPipeline(options) {
        return this.Repository.Pipeline.Step.retrieveStep(options);
    }
    /**
     * Update the pipelines configuration for a repository.
     * Alternative usage: Repository.Pipeline.Configuration.updateConfiguration
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-put
     * @param options Request options.
     */
    async updateRepositoryPipelineConfiguration(options) {
        return this.Repository.Pipeline.Configuration.updateConfiguration(options);
    }
    /**
     * Retrieve the repository pipelines configuration.
     * Alternative usage: Repository.Pipeline.Configuration.retrieveConfiguration
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-get
     * @param options Request options.
     */
    async retrieveRepositoryPipelineConfiguration(options) {
        return this.Repository.Pipeline.Configuration.retrieveConfiguration(options);
    }
    /**
     * Update the next build number that should be assigned to a pipeline. The next build number that will be configured has to be strictly higher than the current latest build number for this repository.
     * Alternative usage: Repository.Pipeline.Configuration.Build.updateBuildNumber
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-build-number-put
     * @param options Request options.
     */
    async updateRepositoryPipelineConfigurationBuildNumber(options) {
        return this.Repository.Pipeline.Configuration.Build.updateBuildNumber(options);
    }
    /**
     * Create a schedule for the given repository.
     * Alternative usage: Repository.Pipeline.Configuration.Schedule.createSchedule
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-post
     * @param options Request options.
     */
    async createRepositoryPipelineConfigurationSchedule(options) {
        return this.Repository.Pipeline.Configuration.Schedule.createSchedule(options);
    }
    /**
     * Retrieve the configured schedules for the given repository.
     * Alternative usage: Repository.Pipeline.Configuration.Schedule.retrieveSchedules
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-get
     * @param options Request options.
     */
    async retrieveRepositoryPipelineConfigurationSchedules(options) {
        return this.Repository.Pipeline.Configuration.Schedule.retrieveSchedules(options);
    }
    /**
     * Update a schedule.
     * Alternative usage: Repository.Pipeline.Configuration.Schedule.updateSchedule
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-schedule-uuid-put
     * @param options Request options.
     */
    async updateRepositoryPipelineConfigurationSchedule(options) {
        return this.Repository.Pipeline.Configuration.Schedule.updateSchedule(options);
    }
    /**
     * Retrieve a schedule by its UUID.
     * Alternative usage: Repository.Pipeline.Configuration.Schedule.retrieveSchedule
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-schedule-uuid-get
     * @param options Request options.
     */
    async retrieveRepositoryPipelineConfigurationSchedule(options) {
        return this.Repository.Pipeline.Configuration.Schedule.retrieveSchedule(options);
    }
    /**
     * Delete a schedule.
     * Alternative usage: Repository.Pipeline.Configuration.Schedule.deleteSchedule
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-schedule-uuid-delete
     * @param options Request options.
     */
    async deleteRepositoryPipelineConfigurationSchedule(options) {
        return this.Repository.Pipeline.Configuration.Schedule.deleteSchedule(options);
    }
    /**
     * Find repository level variables.
     * Alternative usage: Repository.Pipeline.Configuration.Variable.getVariables
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-get
     * @param options Request options.
     */
    async getRepositoryPipelineConfigurationVariables(options) {
        return this.Repository.Pipeline.Configuration.Variable.getVariables(options);
    }
    /**
     * Create a repository level variable.
     * Alternative usage: Repository.Pipeline.Configuration.Variable.createVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-post
     * @param options Request options.
     */
    async createRepositoryPipelineConfigurationVariable(options) {
        return this.Repository.Pipeline.Configuration.Variable.createVariable(options);
    }
    /**
     * Retrieve a repository level variable.
     * Alternative usage: Repository.Pipeline.Configuration.Variable.getVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-variable-uuid-get
     * @param options Request options.
     */
    async getRepositoryPipelineConfigurationVariable(options) {
        return this.Repository.Pipeline.Configuration.Variable.getVariable(options);
    }
    /**
     * Update a repository level variable.
     * Alternative usage: Repository.Pipeline.Configuration.Variable.updateVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-variable-uuid-put
     * @param options Request options.
     */
    async updateRepositoryPipelineConfigurationVariable(options) {
        return this.Repository.Pipeline.Configuration.Variable.updateVariable(options);
    }
    /**
     * Delete a repository level variable.
     * Alternative usage: Repository.Pipeline.Configuration.Variable.deleteVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-variable-uuid-delete
     * @param options Request options.
     */
    async deleteRepositoryPipelineConfigurationVariable(options) {
        return this.Repository.Pipeline.Configuration.Variable.deleteVariable(options);
    }
    /**
  * Returns all pull requests on the specified repository.
  
  By default only open pull requests are returned. This can be controlled
  using the `state` query parameter. To retrieve pull requests that are
  in one of multiple states, repeat the `state` parameter for each
  individual state.
  
  This endpoint also supports filtering and sorting of the results. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering) for more details.
  * Alternative usage: Repository.Pullrequest.getPullrequests
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-get
  * @param options Request options.
  */
    async getRepositoryPullrequests(options) {
        return this.Repository.Pullrequest.getPullrequests(options);
    }
    /**
  * Creates a new pull request where the destination repository is
  this repository and the author is the authenticated user.
  
  The minimum required fields to create a pull request are `title` and
  `source`, specified by a branch name.
  
  ```
  curl https://api.bitbucket.org/2.0/repositories/my-workspace/my-repository/pullrequests \
      -u my-username:my-password \
      --request POST \
      --header 'Content-Type: application/json' \
      --data '{
          "title": "My Title",
          "source": {
              "branch": {
                  "name": "staging"
              }
          }
      }'
  ```
  
  If the pull request's `destination` is not specified, it will default
  to the `repository.mainbranch`. To open a pull request to a
  different branch, say from a feature branch to a staging branch,
  specify a `destination` (same format as the `source`):
  
  ```
  {
      "title": "My Title",
      "source": {
          "branch": {
              "name": "my-feature-branch"
          }
      },
      "destination": {
          "branch": {
              "name": "staging"
          }
      }
  }
  ```
  
  Reviewers can be specified by adding an array of user objects as the
  `reviewers` property.
  
  ```
  {
      "title": "My Title",
      "source": {
          "branch": {
              "name": "my-feature-branch"
          }
      },
      "reviewers": [
          {
              "uuid": "{504c3b62-8120-4f0c-a7bc-87800b9d6f70}"
          }
      ]
  }
  ```
  
  Other fields:
  
  * `description` - a string
  * `close_source_branch` - boolean that specifies if the source branch should be closed upon merging
  * Alternative usage: Repository.Pullrequest.createPullrequest
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-post
  * @param options Request options.
  */
    async createRepositoryPullrequest(options) {
        return this.Repository.Pullrequest.createPullrequest(options);
    }
    /**
  * Returns a paginated list of the pull request's activity log.
  
  This handler serves both a v20 and internal endpoint. The v20 endpoint
  returns reviewer comments, updates, approvals and request changes. The internal
  endpoint includes those plus tasks and attachments.
  
  Comments created on a file or a line of code have an inline property.
  
  Comment example:
  ```
  {
      "pagelen": 20,
      "values": [
          {
              "comment": {
                  "links": {
                      "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695/comments/118571088"
                      },
                      "html": {
                          "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695/_/diff#comment-118571088"
                      }
                  },
                  "deleted": false,
                  "pullrequest": {
                      "type": "pullrequest",
                      "id": 5695,
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                          },
                          "html": {
                              "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                          }
                      },
                      "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
                  },
                  "content": {
                      "raw": "inline with to a dn from lines",
                      "markup": "markdown",
                      "html": "<p>inline with to a dn from lines</p>",
                      "type": "rendered"
                  },
                  "created_on": "2019-09-27T00:33:46.039178+00:00",
                  "user": {
                      "display_name": "Name Lastname",
                      "uuid": "{}",
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/users/%7B%7D"
                          },
                          "html": {
                              "href": "https://bitbucket.org/%7B%7D/"
                          },
                          "avatar": {
                              "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/:/128"
                          }
                      },
                      "type": "user",
                      "nickname": "Name",
                      "account_id": ""
                  },
                  "created_on": "2019-09-27T00:33:46.039178+00:00",
                  "user": {
                      "display_name": "Name Lastname",
                      "uuid": "{}",
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/users/%7B%7D"
                          },
                          "html": {
                              "href": "https://bitbucket.org/%7B%7D/"
                          },
                          "avatar": {
                              "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/:/128"
                          }
                      },
                      "type": "user",
                      "nickname": "Name",
                      "account_id": ""
                  },
                  "updated_on": "2019-09-27T00:33:46.055384+00:00",
                  "inline": {
                      "context_lines": "",
                      "to": null,
                      "path": "",
                      "outdated": false,
                      "from": 211
                  },
                  "type": "pullrequest_comment",
                  "id": 118571088
              },
              "pull_request": {
                  "type": "pullrequest",
                  "id": 5695,
                  "links": {
                      "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                      },
                      "html": {
                          "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                      }
                  },
                  "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
              }
          }
      ]
  }
  ```
  
  Updates include a state property of OPEN, MERGED, or DECLINED.
  
  Update example:
  ```
  {
      "pagelen": 20,
      "values": [
          {
              "update": {
                  "description": "",
                  "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it",
                  "destination": {
                      "commit": {
                          "type": "commit",
                          "hash": "6a2c16e4a152",
                          "links": {
                              "self": {
                                  "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/commit/6a2c16e4a152"
                              },
                              "html": {
                                  "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/commits/6a2c16e4a152"
                              }
                          }
                      },
                      "branch": {
                          "name": "master"
                      },
                      "repository": {
                          "name": "Atlaskit-MK-2",
                          "type": "repository",
                          "full_name": "atlassian/atlaskit-mk-2",
                          "links": {
                              "self": {
                                  "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2"
                              },
                              "html": {
                                  "href": "https://bitbucket.org/atlassian/atlaskit-mk-2"
                              },
                              "avatar": {
                                  "href": "https://bytebucket.org/ravatar/%7B%7D?ts=js"
                              }
                          },
                          "uuid": "{}"
                      }
                  },
                  "reason": "",
                  "source": {
                      "commit": {
                          "type": "commit",
                          "hash": "728c8bad1813",
                          "links": {
                              "self": {
                                  "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/commit/728c8bad1813"
                              },
                              "html": {
                                  "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/commits/728c8bad1813"
                              }
                          }
                      },
                      "branch": {
                          "name": "username/NONE-add-onClick-prop-for-accessibility"
                      },
                      "repository": {
                          "name": "Atlaskit-MK-2",
                          "type": "repository",
                          "full_name": "atlassian/atlaskit-mk-2",
                          "links": {
                              "self": {
                                  "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2"
                              },
                              "html": {
                                  "href": "https://bitbucket.org/atlassian/atlaskit-mk-2"
                              },
                              "avatar": {
                                  "href": "https://bytebucket.org/ravatar/%7B%7D?ts=js"
                              }
                          },
                          "uuid": "{}"
                      }
                  },
                  "state": "OPEN",
                  "author": {
                      "display_name": "Name Lastname",
                      "uuid": "{}",
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/users/%7B%7D"
                          },
                          "html": {
                              "href": "https://bitbucket.org/%7B%7D/"
                          },
                          "avatar": {
                              "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/:/128"
                          }
                      },
                      "type": "user",
                      "nickname": "Name",
                      "account_id": ""
                  },
                  "date": "2019-05-10T06:48:25.305565+00:00"
              },
              "pull_request": {
                  "type": "pullrequest",
                  "id": 5695,
                  "links": {
                      "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                      },
                      "html": {
                          "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                      }
                  },
                  "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
              }
          }
      ]
  }
  ```
  
  Approval example:
  ```
  {
      "pagelen": 20,
      "values": [
          {
              "approval": {
                  "date": "2019-09-27T00:37:19.849534+00:00",
                  "pullrequest": {
                      "type": "pullrequest",
                      "id": 5695,
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                          },
                          "html": {
                              "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                          }
                      },
                      "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
                  },
                  "user": {
                      "display_name": "Name Lastname",
                      "uuid": "{}",
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/users/%7B%7D"
                          },
                          "html": {
                              "href": "https://bitbucket.org/%7B%7D/"
                          },
                          "avatar": {
                              "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/:/128"
                          }
                      },
                      "type": "user",
                      "nickname": "Name",
                      "account_id": ""
                  }
              },
              "pull_request": {
                  "type": "pullrequest",
                  "id": 5695,
                  "links": {
                      "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                      },
                      "html": {
                          "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                      }
                  },
                  "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
              }
          }
      ]
  }
  ```
  * Alternative usage: Repository.Pullrequest.getActivityLog
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-activity-get
  * @param options Request options.
  */
    async getRepositoryPullrequestActivityLog(options) {
        return this.Repository.Pullrequest.getActivityLog(options);
    }
    /**
     * Returns the specified pull request.
     * Alternative usage: Repository.Pullrequest.getPullrequest
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-get
     * @param options Request options.
     */
    async getRepositoryPullrequest(options) {
        return this.Repository.Pullrequest.getPullrequest(options);
    }
    /**
  * Mutates the specified pull request.
  
  This can be used to change the pull request's branches or description.
  
  Only open pull requests can be mutated.
  * Alternative usage: Repository.Pullrequest.mutatePullrequest
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-put
  * @param options Request options.
  */
    async mutateRepositoryPullrequest(options) {
        return this.Repository.Pullrequest.mutatePullrequest(options);
    }
    /**
     * Approve the specified pull request as the authenticated user.
     * Alternative usage: Repository.Pullrequest.approvePullrequest
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-approve-post
     * @param options Request options.
     */
    async approveRepositoryPullrequest(options) {
        return this.Repository.Pullrequest.approvePullrequest(options);
    }
    /**
     * Declines the pull request.
     * Alternative usage: Repository.Pullrequest.declinePullrequest
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-decline-post
     * @param options Request options.
     */
    async declineRepositoryPullrequest(options) {
        return this.Repository.Pullrequest.declinePullrequest(options);
    }
    /**
     * Merges the pull request.
     * Alternative usage: Repository.Pullrequest.mergePullrequest
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-merge-post
     * @param options Request options.
     */
    async mergeRepositoryPullrequest(options) {
        return this.Repository.Pullrequest.mergePullrequest(options);
    }
    /**
  * Returns all statuses (e.g. build results) for the given pull
  request.
  * Alternative usage: Repository.Pullrequest.getPullrequestStatuses
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-statuses-get
  * @param options Request options.
  */
    async getRepositoryPullrequestStatuses(options) {
        return this.Repository.Pullrequest.getPullrequestStatuses(options);
    }
    /**
  * Returns a paginated list of the pull request's comments.
  
  This includes both global, inline comments and replies.
  
  The default sorting is oldest to newest and can be overridden with
  the `sort` query parameter.
  
  This endpoint also supports filtering and sorting of the results. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering) for more
  details.
  * Alternative usage: Repository.Pullrequest.Comment.getComments
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-get
  * @param options Request options.
  */
    async getRepositoryPullrequestComments(options) {
        return this.Repository.Pullrequest.Comment.getComments(options);
    }
    /**
  * Creates a new pull request comment.
  
  Returns the newly created pull request comment.
  * Alternative usage: Repository.Pullrequest.Comment.createComment
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-post
  * @param options Request options.
  */
    async createRepositoryPullrequestComment(options) {
        return this.Repository.Pullrequest.Comment.createComment(options);
    }
    /**
     * Deletes a specific pull request comment.
     * Alternative usage: Repository.Pullrequest.Comment.deleteComment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-comment-id-delete
     * @param options Request options.
     */
    async deleteRepositoryPullrequestComment(options) {
        return this.Repository.Pullrequest.Comment.deleteComment(options);
    }
    /**
     * Returns a specific pull request comment.
     * Alternative usage: Repository.Pullrequest.Comment.getComment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-comment-id-get
     * @param options Request options.
     */
    async getRepositoryPullrequestComment(options) {
        return this.Repository.Pullrequest.Comment.getComment(options);
    }
    /**
     * Updates a specific pull request comment.
     * Alternative usage: Repository.Pullrequest.Comment.updateComment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-comment-id-put
     * @param options Request options.
     */
    async updateRepositoryPullrequestComment(options) {
        return this.Repository.Pullrequest.Comment.updateComment(options);
    }
    /**
  * Returns a paginated list of the pull request's commits.
  
  These are the commits that are being merged into the destination
  branch when the pull requests gets accepted.
  * Alternative usage: Repository.Pullrequest.Commit.getCommits
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-commits-get
  * @param options Request options.
  */
    async getRepositoryPullrequestCommits(options) {
        return this.Repository.Pullrequest.Commit.getCommits(options);
    }
    /**
  * Returns a list of all open branches within the specified repository.
   Results will be in the order the source control manager returns them.
  
          ```
          $ curl -s https://api.bitbucket.org/2.0/repositories/atlassian/aui/refs/branches?pagelen=1 | jq .
          {
            "pagelen": 1,
            "size": 187,
            "values": [
              {
                "name": "issue-9.3/AUI-5343-assistive-class",
                "links": {
                  "commits": {
                    "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commits/issue-9.3/AUI-5343-assistive-class"
                  },
                  "self": {
                    "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/refs/branches/issue-9.3/AUI-5343-assistive-class"
                  },
                  "html": {
                    "href": "https://bitbucket.org/atlassian/aui/branch/issue-9.3/AUI-5343-assistive-class"
                  }
                },
                "default_merge_strategy": "squash",
                "merge_strategies": [
                  "merge_commit",
                  "squash",
                  "fast_forward"
                ],
                "type": "branch",
                "target": {
                  "hash": "e5d1cde9069fcb9f0af90403a4de2150c125a148",
                  "repository": {
                    "links": {
                      "self": {
                        "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui"
                      },
                      "html": {
                        "href": "https://bitbucket.org/atlassian/aui"
                      },
                      "avatar": {
                        "href": "https://bytebucket.org/ravatar/%7B585074de-7b60-4fd1-81ed-e0bc7fafbda5%7D?ts=86317"
                      }
                    },
                    "type": "repository",
                    "name": "aui",
                    "full_name": "atlassian/aui",
                    "uuid": "{585074de-7b60-4fd1-81ed-e0bc7fafbda5}"
                  },
                  "links": {
                    "self": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/e5d1cde9069fcb9f0af90403a4de2150c125a148"
                    },
                    "comments": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/e5d1cde9069fcb9f0af90403a4de2150c125a148/comments"
                    },
                    "patch": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/patch/e5d1cde9069fcb9f0af90403a4de2150c125a148"
                    },
                    "html": {
                      "href": "https://bitbucket.org/atlassian/aui/commits/e5d1cde9069fcb9f0af90403a4de2150c125a148"
                    },
                    "diff": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/diff/e5d1cde9069fcb9f0af90403a4de2150c125a148"
                    },
                    "approve": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/e5d1cde9069fcb9f0af90403a4de2150c125a148/approve"
                    },
                    "statuses": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/e5d1cde9069fcb9f0af90403a4de2150c125a148/statuses"
                    }
                  },
                  "author": {
                    "raw": "Marcin Konopka <mkonopka@atlassian.com>",
                    "type": "author",
                    "user": {
                      "display_name": "Marcin Konopka",
                      "uuid": "{47cc24f4-2a05-4420-88fe-0417535a110a}",
                      "links": {
                        "self": {
                          "href": "https://api.bitbucket.org/2.0/users/%7B47cc24f4-2a05-4420-88fe-0417535a110a%7D"
                        },
                        "html": {
                          "href": "https://bitbucket.org/%7B47cc24f4-2a05-4420-88fe-0417535a110a%7D/"
                        },
                        "avatar": {
                          "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/initials/MK-1.png"
                        }
                      },
                      "nickname": "Marcin Konopka",
                      "type": "user",
                      "account_id": "60113d2b47a9540069f4de03"
                    }
                  },
                  "parents": [
                    {
                      "hash": "87f7fc92b00464ae47b13ef65c91884e4ac9be51",
                      "type": "commit",
                      "links": {
                        "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/87f7fc92b00464ae47b13ef65c91884e4ac9be51"
                        },
                        "html": {
                          "href": "https://bitbucket.org/atlassian/aui/commits/87f7fc92b00464ae47b13ef65c91884e4ac9be51"
                        }
                      }
                    }
                  ],
                  "date": "2021-04-13T13:44:49+00:00",
                  "message": "wip
  ",
                  "type": "commit"
                }
              }
            ],
            "page": 1,
            "next": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/refs/branches?pagelen=1&page=2"
          }
          ```
  
          Branches support [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering)
          that can be used to search for specific branches. For instance, to find
          all branches that have "stab" in their name:
  
          ```
          curl -s https://api.bitbucket.org/2.0/repositories/atlassian/aui/refs/branches -G --data-urlencode 'q=name ~ "stab"'
          ```
  
          By default, results will be in the order the underlying source control system returns them and identical to
          the ordering one sees when running "$ git branch --list". Note that this follows simple
          lexical ordering of the ref names.
  
          This can be undesirable as it does apply any natural sorting semantics, meaning for instance that tags are
          sorted ["v10", "v11", "v9"] instead of ["v9", "v10", "v11"].
  
          Sorting can be changed using the ?q= query parameter. When using ?q=name to explicitly sort on ref name,
          Bitbucket will apply natural sorting and interpret numerical values as numbers instead of strings.
  * Alternative usage: Repository.Branch.getOpenBranches
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-branches-get
  * @param options Request options.
  */
    async getRepositoryOpenBranches(options) {
        return this.Repository.Branch.getOpenBranches(options);
    }
    /**
  * Creates a new branch in the specified repository.
  
  The payload of the POST should consist of a JSON document that
  contains the name of the tag and the target hash.
  
  ```
  curl https://api.bitbucket.org/2.0/repositories/seanfarley/hg/refs/branches \
  -s -u seanfarley -X POST -H "Content-Type: application/json" \
  -d '{
      "name" : "smf/create-feature",
      "target" : {
          "hash" : "default",
      }
  }'
  ```
  
  This call requires authentication. Private repositories require the
  caller to authenticate with an account that has appropriate
  authorization.
  
  The branch name should not include any prefixes (e.g.
  refs/heads). This endpoint does support using short hash prefixes for
  the commit hash, but it may return a 400 response if the provided
  prefix is ambiguous. Using a full commit hash is the preferred
  approach.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-branches-post
  * @param options Request options.
  */
    async createRepositoryBranch(options) {
        return this.Repository.Branch.createBranch(options);
    }
    /**
  * Returns a branch object within the specified repository.
  
  This call requires authentication. Private repositories require the
  caller to authenticate with an account that has appropriate
  authorization.
  
  For Git, the branch name should not include any prefixes (e.g.
  refs/heads).
  * Alternative usage: Repository.Branch.getBranch
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-branches-name-get
  * @param options Request options.
  */
    async getRepositoryBranch(options) {
        return this.Repository.Branch.getBranch(options);
    }
    /**
  * Delete a branch in the specified repository.
  
  The main branch is not allowed to be deleted and will return a 400
  response.
  
  The branch name should not include any prefixes (e.g.
  refs/heads).
  * Alternative usage: Repository.Branch.deleteBranch
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-branches-name-delete
  * @param options Request options.
  */
    async deleteRepositoryBranch(options) {
        return this.Repository.Branch.deleteBranch(options);
    }
    /**
  * Returns a paginated list of all branch restrictions on the
  repository.
  * Alternative usage: Repository.Branch.Restriction.getRestrictions
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-group-branch-restrictions
  * @param options Request options.
  */
    async getRepositoryBranchRestrictions(options) {
        return this.Repository.Branch.Restriction.getRestrictions(options);
    }
    /**
  * Creates a new branch restriction rule for a repository.
  
  `kind` describes what will be restricted. Allowed values include:
  `push`, `force`, `delete`, `restrict_merges`, `require_tasks_to_be_completed`,
  `require_approvals_to_merge`, `require_default_reviewer_approvals_to_merge`,
  `require_no_changes_requested`, `require_passing_builds_to_merge`, `require_commits_behind`,
  `reset_pullrequest_approvals_on_change`, `smart_reset_pullrequest_approvals`,
  `reset_pullrequest_changes_requested_on_change`, `require_all_dependencies_merged`,
  `enforce_merge_checks`, and `allow_auto_merge_when_builds_pass`.
  
  Different kinds of branch restrictions have different requirements:
  
  * `push` and `restrict_merges` require `users` and `groups` to be
    specified. Empty lists are allowed, in which case permission is
    denied for everybody.
  
  The restriction applies to all branches that match. There are
  two ways to match a branch. It is configured in `branch_match_kind`:
  
  1. `glob`: Matches a branch against the `pattern`. A `'*'` in
     `pattern` will expand to match zero or more characters, and every
     other character matches itself. For example, `'foo*'` will match
     `'foo'` and `'foobar'`, but not `'barfoo'`. `'*'` will match all
     branches.
  2. `branching_model`: Matches a branch against the repository's
     branching model. The `branch_type` controls the type of branch
     to match. Allowed values include: `production`, `development`,
     `bugfix`, `release`, `feature` and `hotfix`.
  
  The combination of `kind` and match must be unique. This means that
  two `glob` restrictions in a repository cannot have the same `kind` and
  `pattern`. Additionally, two `branching_model` restrictions in a
  repository cannot have the same `kind` and `branch_type`.
  
  `users` and `groups` are lists of users and groups that are except from
  the restriction. They can only be configured in `push` and
  `restrict_merges` restrictions. The `push` restriction stops a user
  pushing to matching branches unless that user is in `users` or is a
  member of a group in `groups`. The `restrict_merges` stops a user
  merging pull requests to matching branches unless that user is in
  `users` or is a member of a group in `groups`. Adding new users or
  groups to an existing restriction should be done via `PUT`.
  
  Note that branch restrictions with overlapping matchers is allowed,
  but the resulting behavior may be surprising.
  * Alternative usage: Repository.Branch.Restriction.createRestriction
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-post
  * @param options Request options.
  */
    async createRepositoryBranchRestriction(options) {
        return this.Repository.Branch.Restriction.createRestriction(options);
    }
    /**
     * Returns a specific branch restriction rule.
     * Alternative usage: Repository.Branch.Restriction.getRestriction
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-id-get
     * @param options Request options.
     */
    async getRepositoryBranchRestriction(options) {
        return this.Repository.Branch.Restriction.getRestriction(options);
    }
    /**
  * Updates an existing branch restriction rule.
  
  Fields not present in the request body are ignored.
  
  See [`POST`](/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-post) for details.
  * Alternative usage: Repository.Branch.Restriction.updateRestriction
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-id-put
  * @param options Request options.
  */
    async updateRepositoryBranchRestriction(options) {
        return this.Repository.Branch.Restriction.updateRestriction(options);
    }
    /**
     * Deletes an existing branch restriction rule.
     * Alternative usage: Repository.Branch.Restriction.deleteRestriction
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-id-delete
     * @param options Request options.
     */
    async deleteRepositoryBranchRestriction(options) {
        return this.Repository.Branch.Restriction.deleteRestriction(options);
    }
    /**
     * Returns the specified commit.
     * Alternative usage: Repository.Commit.getCommit
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-get
     * @param options Request options.
     */
    async getRepositoryCommit(options) {
        return this.Repository.Commit.getCommit(options);
    }
    /**
  * Returns a paginated list of commits that modified the specified file.
  
  Commits are returned in reverse chronological order. This is roughly
  equivalent to the following commands:
  
      $ git log --follow --date-order <sha> <path>
  
  By default, Bitbucket will follow renames and the path name in the
  returned entries reflects that. This can be turned off using the
  `?renames=false` query parameter.
  
  Results are returned in descending chronological order by default, and
  like most endpoints you can
  [filter and sort](/cloud/bitbucket/rest/intro/#filtering) the response to
  only provide exactly the data you want.
  
  For example, if you wanted to find commits made before 2011-05-18
  against a file named `README.rst`, but you only wanted the path and
  date, your query would look like this:
  
  ```
  $ curl 'https://api.bitbucket.org/2.0/repositories/evzijst/dogslow/filehistory/master/README.rst'\
    '?fields=values.next,values.path,values.commit.date&q=commit.date<=2011-05-18'
  {
    "values": [
      {
        "commit": {
          "date": "2011-05-17T07:32:09+00:00"
        },
        "path": "README.rst"
      },
      {
        "commit": {
          "date": "2011-05-16T06:33:28+00:00"
        },
        "path": "README.txt"
      },
      {
        "commit": {
          "date": "2011-05-16T06:15:39+00:00"
        },
        "path": "README.txt"
      }
    ]
  }
  ```
  
  In the response you can see that the file was renamed to `README.rst`
  by the commit made on 2011-05-16, and was previously named `README.txt`.
  * Alternative usage: Repository.Commit.getCommitsByFile
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-source/#api-repositories-workspace-repo-slug-filehistory-commit-path-get
  * @param options Request options.
  */
    async getRepositoryCommitsByFile(options) {
        return this.Repository.Commit.getCommitsByFile(options);
    }
    /**
  * Identical to `GET /repositories/{workspace}/{repo_slug}/commits`,
  except that POST allows clients to place the include and exclude
  parameters in the request body to avoid URL length issues.
  
  **Note that this resource does NOT support new commit creation.**
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commits-post
  * @param options Request options.
  */
    async getRepositoryCommits(options) {
        return this.Repository.Commit.getCommits(options);
    }
    /**
  * Approve the specified commit as the authenticated user.
  
  This operation is only available to users that have explicit access to
  the repository. In contrast, just the fact that a repository is
  publicly accessible to users does not give them the ability to approve
  commits.
  * Alternative usage: Repository.Commit.Approval.approveCommit
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-approve-post
  * @param options Request options.
  */
    async approveRepositoryCommit(options) {
        return this.Repository.Commit.Approval.approveCommit(options);
    }
    /**
  * Redact the authenticated user's approval of the specified commit.
  
  This operation is only available to users that have explicit access to
  the repository. In contrast, just the fact that a repository is
  publicly accessible to users does not give them the ability to approve
  commits.
  * Alternative usage: Repository.Commit.Approval.redactApproval
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-approve-delete
  * @param options Request options.
  */
    async redactRepositoryCommitApproval(options) {
        return this.Repository.Commit.Approval.redactApproval(options);
    }
    /**
  * Returns the commit's comments.
  
  This includes both global and inline comments.
  
  The default sorting is oldest to newest and can be overridden with
  the `sort` query parameter.
  * Alternative usage: Repository.Commit.Comment.getComments
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-comments-get
  * @param options Request options.
  */
    async getRepositoryCommitComments(options) {
        return this.Repository.Commit.Comment.getComments(options);
    }
    /**
     * Returns the specified commit comment.
     * Alternative usage: Repository.Commit.Comment.getComment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-comments-comment-id-get
     * @param options Request options.
     */
    async getRepositoryCommitComment(options) {
        return this.Repository.Commit.Comment.getComment(options);
    }
    /**
     * Returns all statuses (e.g. build results) for a specific commit.
     * Alternative usage: Repository.Commit.Status.getStatuses
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commit-statuses/#api-repositories-workspace-repo-slug-commit-commit-statuses-get
     * @param options Request options.
     */
    async getRepositoryCommitStatuses(options) {
        return this.Repository.Commit.Status.getStatuses(options);
    }
    /**
  * Creates a new build status against the specified commit.
  
  If the specified key already exists, the existing status object will
  be overwritten.
  
  Example:
  
  ```
  curl https://api.bitbucket.org/2.0/repositories/my-workspace/my-repo/commit/e10dae226959c2194f2b07b077c07762d93821cf/statuses/build/           -X POST -u jdoe -H 'Content-Type: application/json'           -d '{
      "key": "MY-BUILD",
      "state": "SUCCESSFUL",
      "description": "42 tests passed",
      "url": "https://www.example.org/my-build-result"
    }'
  ```
  
  When creating a new commit status, you can use a URI template for the URL.
  Templates are URLs that contain variable names that Bitbucket will
  evaluate at runtime whenever the URL is displayed anywhere similar to
  parameter substitution in
  [Bitbucket Connect](https://developer.atlassian.com/bitbucket/concepts/context-parameters.html).
  For example, one could use `https://foo.com/builds/{repository.full_name}`
  which Bitbucket will turn into `https://foo.com/builds/foo/bar` at render time.
  The context variables available are `repository` and `commit`.
  
  To associate a commit status to a pull request, the refname field must be set to the source branch
  of the pull request.
  
  Example:
  ```
  curl https://api.bitbucket.org/2.0/repositories/my-workspace/my-repo/commit/e10dae226959c2194f2b07b077c07762d93821cf/statuses/build/           -X POST -u jdoe -H 'Content-Type: application/json'           -d '{
      "key": "MY-BUILD",
      "state": "SUCCESSFUL",
      "description": "42 tests passed",
      "url": "https://www.example.org/my-build-result",
      "refname": "my-pr-branch"
    }'
  ```
  * Alternative usage: Repository.Commit.Status.createStatus
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commit-statuses/#api-repositories-workspace-repo-slug-commit-commit-statuses-build-post
  * @param options Request options.
  */
    async createRepositoryCommitStatus(options) {
        return this.Repository.Commit.Status.createStatus(options);
    }
    /**
     * Returns the specified build status for a commit.
     * Alternative usage: Repository.Commit.Status.getStatus
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commit-statuses/#api-repositories-workspace-repo-slug-commit-commit-statuses-build-key-get
     * @param options Request options.
     */
    async getRepositoryCommitStatus(options) {
        return this.Repository.Commit.Status.getStatus(options);
    }
    /**
  * Returns the repository's default reviewers.
  
  These are the users that are automatically added as reviewers on every
  new pull request that is created. To obtain the repository's default reviewers
  as well as the default reviewers inherited from the project, use the
  [effective-default-reveiwers](#api-repositories-workspace-repo-slug-effective-default-reviewers-get) endpoint.
  * Alternative usage: Repository.Reviewer.Default.getReviewers
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-default-reviewers-get
  * @param options Request options.
  */
    async getRepositoryDefaultReviewers(options) {
        return this.Repository.Reviewer.Default.getReviewers(options);
    }
    /**
  * Returns the specified reviewer.
  
  This can be used to test whether a user is among the repository's
  default reviewers list. A 404 indicates that that specified user is not
  a default reviewer.
  * Alternative usage: Repository.Reviewer.Default.getReviewer
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-default-reviewers-target-username-get
  * @param options Request options.
  */
    async getRepositoryDefaultReviewer(options) {
        return this.Repository.Reviewer.Default.getReviewer(options);
    }
    /**
  * Adds the specified user to the repository's list of default
  reviewers.
  
  This method is idempotent. Adding a user a second time has no effect.
  * Alternative usage: Repository.Reviewer.Default.addReviewer
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-default-reviewers-target-username-put
  * @param options Request options.
  */
    async addRepositoryDefaultReviewer(options) {
        return this.Repository.Reviewer.Default.addReviewer(options);
    }
    /**
     * Removes a default reviewer from the repository.
     * Alternative usage: Repository.Reviewer.Default.removeReviewer
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-default-reviewers-target-username-delete
     * @param options Request options.
     */
    async removeRepositoryDefaultReviewer(options) {
        return this.Repository.Reviewer.Default.removeReviewer(options);
    }
    /**
  * Returns the tags in the repository.
  
  By default, results will be in the order the underlying source control system returns them and identical to
  the ordering one sees when running "$ git tag --list". Note that this follows simple
  lexical ordering of the ref names.
  
  This can be undesirable as it does apply any natural sorting semantics, meaning for instance that tags are
  sorted ["v10", "v11", "v9"] instead of ["v9", "v10", "v11"].
  
  Sorting can be changed using the ?sort= query parameter. When using ?sort=name to explicitly sort on ref name,
  Bitbucket will apply natural sorting and interpret numerical values as numbers instead of strings.
  * Alternative usage: Repository.Tag.getTags
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-tags-get
  * @param options Request options.
  */
    async getRepositoryTags(options) {
        return this.Repository.Tag.getTags(options);
    }
    /**
  * Creates a new tag in the specified repository.
  
  The payload of the POST should consist of a JSON document that
  contains the name of the tag and the target hash.
  
  ```
  curl https://api.bitbucket.org/2.0/repositories/jdoe/myrepo/refs/tags \
  -s -u jdoe -X POST -H "Content-Type: application/json" \
  -d '{
      "name" : "new-tag-name",
      "target" : {
          "hash" : "a1b2c3d4e5f6",
      }
  }'
  ```
  
  This endpoint does support using short hash prefixes for the commit
  hash, but it may return a 400 response if the provided prefix is
  ambiguous. Using a full commit hash is the preferred approach.
  * Alternative usage: Repository.Tag.createTag
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-tags-post
  * @param options Request options.
  */
    async createRepositoryTag(options) {
        return this.Repository.Tag.createTag(options);
    }
    /**
  * Returns the specified tag.
  
  ```
  $ curl -s https://api.bitbucket.org/2.0/repositories/seanfarley/hg/refs/tags/3.8 -G | jq .
  {
    "name": "3.8",
    "links": {
      "commits": {
        "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commits/3.8"
      },
      "self": {
        "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/refs/tags/3.8"
      },
      "html": {
        "href": "https://bitbucket.org/seanfarley/hg/commits/tag/3.8"
      }
    },
    "tagger": {
      "raw": "Matt Mackall <mpm@selenic.com>",
      "type": "author",
      "user": {
        "username": "mpmselenic",
        "nickname": "mpmselenic",
        "display_name": "Matt Mackall",
        "type": "user",
        "uuid": "{a4934530-db4c-419c-a478-9ab4964c2ee7}",
        "links": {
          "self": {
            "href": "https://api.bitbucket.org/2.0/users/mpmselenic"
          },
          "html": {
            "href": "https://bitbucket.org/mpmselenic/"
          },
          "avatar": {
            "href": "https://bitbucket.org/account/mpmselenic/avatar/32/"
          }
        }
      }
    },
    "date": "2016-05-01T18:52:25+00:00",
    "message": "Added tag 3.8 for changeset f85de28eae32",
    "type": "tag",
    "target": {
      "hash": "f85de28eae32e7d3064b1a1321309071bbaaa069",
      "repository": {
        "links": {
          "self": {
            "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg"
          },
          "html": {
            "href": "https://bitbucket.org/seanfarley/hg"
          },
          "avatar": {
            "href": "https://bitbucket.org/seanfarley/hg/avatar/32/"
          }
        },
        "type": "repository",
        "name": "hg",
        "full_name": "seanfarley/hg",
        "uuid": "{c75687fb-e99d-4579-9087-190dbd406d30}"
      },
      "links": {
        "self": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/f85de28eae32e7d3064b1a1321309071bbaaa069"
        },
        "comments": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/f85de28eae32e7d3064b1a1321309071bbaaa069/comments"
        },
        "patch": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/patch/f85de28eae32e7d3064b1a1321309071bbaaa069"
        },
        "html": {
          "href": "https://bitbucket.org/seanfarley/hg/commits/f85de28eae32e7d3064b1a1321309071bbaaa069"
        },
        "diff": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/diff/f85de28eae32e7d3064b1a1321309071bbaaa069"
        },
        "approve": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/f85de28eae32e7d3064b1a1321309071bbaaa069/approve"
        },
        "statuses": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/f85de28eae32e7d3064b1a1321309071bbaaa069/statuses"
        }
      },
      "author": {
        "raw": "Sean Farley <sean@farley.io>",
        "type": "author",
        "user": {
          "username": "seanfarley",
          "nickname": "seanfarley",
          "display_name": "Sean Farley",
          "type": "user",
          "uuid": "{a295f8a8-5876-4d43-89b5-3ad8c6c3c51d}",
          "links": {
            "self": {
              "href": "https://api.bitbucket.org/2.0/users/seanfarley"
            },
            "html": {
              "href": "https://bitbucket.org/seanfarley/"
            },
            "avatar": {
              "href": "https://bitbucket.org/account/seanfarley/avatar/32/"
            }
          }
        }
      },
      "parents": [
        {
          "hash": "9a98d0e5b07fc60887f9d3d34d9ac7d536f470d2",
          "type": "commit",
          "links": {
            "self": {
              "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/9a98d0e5b07fc60887f9d3d34d9ac7d536f470d2"
            },
            "html": {
              "href": "https://bitbucket.org/seanfarley/hg/commits/9a98d0e5b07fc60887f9d3d34d9ac7d536f470d2"
            }
          }
        }
      ],
      "date": "2016-05-01T04:21:17+00:00",
      "message": "debian: alphabetize build deps",
      "type": "commit"
    }
  }
  ```
  * Alternative usage: Repository.Tag.getTag
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-tags-name-get
  * @param options Request options.
  */
    async getRepositoryTag(options) {
        return this.Repository.Tag.getTag(options);
    }
    /**
  * Delete a tag in the specified repository.
  
  The tag name should not include any prefixes (e.g. refs/tags).
  * Alternative usage: Repository.Tag.deleteTag
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-tags-name-delete
  * @param options Request options.
  */
    async deleteRepositoryTag(options) {
        return this.Repository.Tag.deleteTag(options);
    }
    /**
     * Find environments
     * Alternative usage: Repository.Environment.getEnvironments
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-environments-get
     * @param options Request options.
     */
    async getRepositoryEnvironments(options) {
        return this.Repository.Environment.getEnvironments(options);
    }
    /**
     * Create an environment.
     * Alternative usage: Repository.Environment.createEnvironment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-environments-post
     * @param options Request options.
     */
    async createRepositoryEnvironment(options) {
        return this.Repository.Environment.createEnvironment(options);
    }
    /**
     * Retrieve an environment
     * Alternative usage: Repository.Environment.getEnvironment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-environments-environment-uuid-get
     * @param options Request options.
     */
    async getRepositoryEnvironment(options) {
        return this.Repository.Environment.getEnvironment(options);
    }
    /**
     * Delete an environment
     * Alternative usage: Repository.Environment.deleteEnvironment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-environments-environment-uuid-delete
     * @param options Request options.
     */
    async deleteRepositoryEnvironment(options) {
        return this.Repository.Environment.deleteEnvironment(options);
    }
    /**
     * Find deployment environment level variables.
     * Alternative usage: Repository.Environment.Variable.getVariables
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-deployments-config-environments-environment-uuid-variables-get
     * @param options Request options.
     */
    async getRepositoryEnvironmentVariables(options) {
        return this.Repository.Environment.Variable.getVariables(options);
    }
    /**
     * Create a deployment environment level variable.
     * Alternative usage: Repository.Environment.Variable.createVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-deployments-config-environments-environment-uuid-variables-post
     * @param options Request options.
     */
    async createRepositoryEnvironmentVariable(options) {
        return this.Repository.Environment.Variable.createVariable(options);
    }
    /**
     * Update a deployment environment level variable.
     * Alternative usage: Repository.Environment.Variable.updateVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-deployments-config-environments-environment-uuid-variables-variable-uuid-put
     * @param options Request options.
     */
    async updateRepositoryEnvironmentVariable(options) {
        return this.Repository.Environment.Variable.updateVariable(options);
    }
    /**
     * Delete a deployment environment level variable.
     * Alternative usage: Repository.Environment.Variable.deleteVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-deployments-config-environments-environment-uuid-variables-variable-uuid-delete
     * @param options Request options.
     */
    async deleteRepositoryEnvironmentVariable(options) {
        return this.Repository.Environment.Variable.deleteVariable(options);
    }
    /**
  * Returns a paginated list of all the forks of the specified
  repository.
  * Alternative usage: Repository.Fork.getForks
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-forks-get
  * @param options Request options.
  */
    async getRepositoryForks(options) {
        return this.Repository.Fork.getForks(options);
    }
    /**
  * Creates a new fork of the specified repository.
  
  #### Forking a repository
  
  To create a fork, specify the workspace explicitly as part of the
  request body:
  
  ```
  $ curl -X POST -u jdoe https://api.bitbucket.org/2.0/repositories/atlassian/bbql/forks \
    -H 'Content-Type: application/json' -d '{
      "name": "bbql_fork",
      "workspace": {
        "slug": "atlassian"
      }
  }'
  ```
  
  To fork a repository into the same workspace, also specify a new `name`.
  
  When you specify a value for `name`, it will also affect the `slug`.
  The `slug` is reflected in the repository URL of the new fork. It is
  derived from `name` by substituting non-ASCII characters, removes
  whitespace, and changes characters to lower case. For example,
  `My repo` would turn into `my_repo`.
  
  You need contributor access to create new forks within a workspace.
  
  
  #### Change the properties of a new fork
  
  By default the fork inherits most of its properties from the parent.
  However, since the optional POST body document follows the normal
  `repository` JSON schema and you can override the new fork's
  properties.
  
  Properties that can be overridden include:
  
  * description
  * fork_policy
  * language
  * mainbranch
  * is_private (note that a private repo's fork_policy might prohibit
    the creation of public forks, in which `is_private=False` would fail)
  * has_issues (to initialize or disable the new repo's issue tracker --
    note that the actual contents of the parent repository's issue
    tracker are not copied during forking)
  * has_wiki (to initialize or disable the new repo's wiki --
    note that the actual contents of the parent repository's wiki are not
    copied during forking)
  * project (when forking into a private project, the fork's `is_private`
    must be `true`)
  
  Properties that cannot be modified include:
  
  * scm
  * parent
  * full_name
  * Alternative usage: Repository.Fork.createFork
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-forks-post
  * @param options Request options.
  */
    async createRepositoryFork(options) {
        return this.Repository.Fork.createFork(options);
    }
    /**
     * Find deployments
     * Alternative usage: Repository.Deployment.getDeployments
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-deployments-get
     * @param options Request options.
     */
    async getRepositoryDeployments(options) {
        return this.Repository.Deployment.getDeployments(options);
    }
    /**
     * Retrieve a deployment
     * Alternative usage: Repository.Deployment.getDeployment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-deployments-deployment-uuid-get
     * @param options Request options.
     */
    async getRepositoryDeployment(options) {
        return this.Repository.Deployment.getDeployment(options);
    }
    /**
     * Returns the currently logged in user.
     * Alternative usage: User.getCurrentUser
     * Documentation: https://developer.atlassian.com/bitbucket/api/2/reference/resource/user
     * @param options Request options.
     */
    async getCurrentUser(options) {
        return this.User.getCurrentUser(options);
    }
    /**
  * Returns all the authenticated user's email addresses. Both
  confirmed and unconfirmed.
  * Alternative usage: User.getCurrentUserEmails
  * Documentation: https://developer.atlassian.com/bitbucket/api/2/reference/resource/user/emails
  * @param options Request options.
  */
    async getCurrentUserEmails(options) {
        return this.User.getCurrentUserEmails(options);
    }
    /**
  * Gets the public information associated with a user account.
  
  If the user's profile is private, `location`, `website` and
  `created_on` elements are omitted.
  
  Note that the user object returned by this operation is changing significantly, due to privacy changes.
  See the [announcement](https://developer.atlassian.com/cloud/bitbucket/bitbucket-api-changes-gdpr/#changes-to-bitbucket-user-objects) for details.
  * Alternative usage: User.getUser
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-users/#api-users-selected-user-get
  * @param options Request options.
  */
    async getUser(options) {
        return this.User.getUser(options);
    }
    /**
  * Returns details about a specific one of the authenticated user's
  email addresses.
  
  Details describe whether the address has been confirmed by the user and
  whether it is the user's primary address or not.
  * Alternative usage: User.getCurrentUserEmail
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-users/#api-user-emails-email-get
  * @param options Request options.
  */
    async getCurrentUserEmail(options) {
        return this.User.getCurrentUserEmail(options);
    }
    /**
  * Returns an object for each repository the caller has explicit access
  to and their effective permission — the highest level of permission the
  caller has. This does not return public repositories that the user was
  not granted any specific permission in, and does not distinguish between
  explicit and implicit privileges.
  
  Permissions can be:
  
  * `admin`
  * `write`
  * `read`
  
  Results may be further [filtered or sorted](/cloud/bitbucket/rest/intro/#filtering) by
  repository or permission by adding the following query string
  parameters:
  
  * `q=repository.name="geordi"` or `q=permission>"read"`
  * `sort=repository.name`
  
  Note that the query parameter values need to be URL escaped so that `=`
  would become `%3D`.
  * Alternative usage: User.Permission.getCurrentUserRepositoryPermissions
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-user-permissions-repositories-get
  * @param options Request options.
  */
    async getCurrentUserRepositoryPermissions(options) {
        return this.User.Permission.getCurrentUserRepositoryPermissions(options);
    }
    /**
  * Returns an object for each workspace the caller is a member of, and
  their effective role - the highest level of privilege the caller has.
  If a user is a member of multiple groups with distinct roles, only the
  highest level is returned.
  
  Permissions can be:
  
  * `owner`
  * `collaborator`
  * `member`
  
  **The `collaborator` role is being removed from the Bitbucket Cloud API. For more information,
  see the [deprecation announcement](/cloud/bitbucket/deprecation-notice-collaborator-role/).**
  
  **When you move your administration from Bitbucket Cloud to admin.atlassian.com, the following fields on
  `workspace_membership` will no longer be present: `last_accessed` and `added_on`. See the
  [deprecation announcement](/cloud/bitbucket/announcement-breaking-change-workspace-membership/).**
  
  Results may be further [filtered or sorted](/cloud/bitbucket/rest/intro/#filtering) by
  workspace or permission by adding the following query string parameters:
  
  * `q=workspace.slug="bbworkspace1"` or `q=permission="owner"`
  * `sort=workspace.slug`
  
  Note that the query parameter values need to be URL escaped so that `=`
  would become `%3D`.
  * Alternative usage: User.Permission.getCurrentUserWorkspaceMemberships
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-workspaces/#api-user-permissions-workspaces-get
  * @param options Request options.
  */
    async getCurrentUserWorkspaceMemberships(options) {
        return this.User.Permission.getCurrentUserWorkspaceMemberships(options);
    }
    /**
     * Returns a paginated list of the user's SSH public keys.
     * Alternative usage: User.SSH.getKeys
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-get
     * @param options Request options.
     */
    async getUserSshKeys(options) {
        return this.User.SSH.getKeys(options);
    }
    /**
  * Adds a new SSH public key to the specified user account and returns the resulting key.
  
  Example:
  
  ```
  $ curl -X POST -H "Content-Type: application/json" -d '{"key": "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKqP3Cr632C2dNhhgKVcon4ldUSAeKiku2yP9O9/bDtY user@myhost"}' https://api.bitbucket.org/2.0/users/{ed08f5e1-605b-4f4a-aee4-6c97628a673e}/ssh-keys
  ```
  * Alternative usage: User.SSH.addKey
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-post
  * @param options Request options.
  */
    async addUserSshKey(options) {
        return this.User.SSH.addKey(options);
    }
    /**
     * Returns a specific SSH public key belonging to a user.
     * Alternative usage: User.SSH.getKey
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-key-id-get
     * @param options Request options.
     */
    async getUserSshKey(options) {
        return this.User.SSH.getKey(options);
    }
    /**
  * Updates a specific SSH public key on a user's account
  
  Note: Only the 'comment' field can be updated using this API. To modify the key or comment values, you must delete and add the key again.
  
  Example:
  
  ```
  $ curl -X PUT -H "Content-Type: application/json" -d '{"label": "Work key"}' https://api.bitbucket.org/2.0/users/{ed08f5e1-605b-4f4a-aee4-6c97628a673e}/ssh-keys/{b15b6026-9c02-4626-b4ad-b905f99f763a}
  ```
  * Alternative usage: User.SSH.updateKey
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-key-id-put
  * @param options Request options.
  */
    async updateUserSshKey(options) {
        return this.User.SSH.updateKey(options);
    }
    /**
     * Deletes a specific SSH public key from a user's account.
     * Alternative usage: User.SSH.deleteKey
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-key-id-delete
     * @param options Request options.
     */
    async deleteUserSshKey(options) {
        return this.User.SSH.deleteKey(options);
    }
    /**
  * Returns a list of workspaces accessible by the authenticated user.
  
  Results may be further [filtered or sorted](/cloud/bitbucket/rest/intro/#filtering) by
  workspace or permission by adding the following query string parameters:
  
  * `q=slug="bbworkspace1"` or `q=is_private=true`
  * `sort=created_on`
  
  Note that the query parameter values need to be URL escaped so that `=`
  would become `%3D`.
  
  **The `collaborator` role is being removed from the Bitbucket Cloud API. For more information,
  see the [deprecation announcement](/cloud/bitbucket/deprecation-notice-collaborator-role/).**
  * Alternative usage: Workspace.getWorkspaces
  * Documentation: https://developer.atlassian.com/bitbucket/api/2/reference/resource/workspaces
  * @param options Request options.
  */
    async getWorkspaces(options) {
        return this.Workspace.getWorkspaces(options);
    }
    /**
     * Returns the requested workspace.
     * Alternative usage: Workspace.getWorkspace
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-workspaces/#api-workspaces-workspace-get
     * @param options Request options.
     */
    async getWorkspace(options) {
        return this.Workspace.getWorkspace(options);
    }
    /**
     * Returns the list of projects in this workspace.
     * Alternative usage: Workspace.Project.getProjects
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-workspaces/#api-workspaces-workspace-projects-get
     * @param options Request options.
     */
    async getWorkspaceProjects(options) {
        return this.Workspace.Project.getProjects(options);
    }
    /**
  * Creates a new project.
  
  Note that the avatar has to be embedded as either a data-url
  or a URL to an external image as shown in the examples below:
  
  ```
  $ body=$(cat << EOF
  {
      "name": "Mars Project",
      "key": "MARS",
      "description": "Software for colonizing mars.",
      "links": {
          "avatar": {
              "href": "data:image/gif;base64,R0lGODlhEAAQAMQAAORHHOVSKudfOulrSOp3WOyDZu6QdvCchPGolfO0o/..."
          }
      },
      "is_private": false
  }
  EOF
  )
  $ curl -H "Content-Type: application/json" \
         -X POST \
         -d "$body" \
         https://api.bitbucket.org/2.0/workspaces/teams-in-space/projects/ | jq .
  {
    // Serialized project document
  }
  ```
  
  or even:
  
  ```
  $ body=$(cat << EOF
  {
      "name": "Mars Project",
      "key": "MARS",
      "description": "Software for colonizing mars.",
      "links": {
          "avatar": {
              "href": "http://i.imgur.com/72tRx4w.gif"
          }
      },
      "is_private": false
  }
  EOF
  )
  $ curl -H "Content-Type: application/json" \
         -X POST \
         -d "$body" \
         https://api.bitbucket.org/2.0/workspaces/teams-in-space/projects/ | jq .
  {
    // Serialized project document
  }
  ```
  * Alternative usage: Workspace.Project.createProject
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-projects/#api-workspaces-workspace-projects-post
  * @param options Request options.
  */
    async createWorkspaceProject(options) {
        return this.Workspace.Project.createProject(options);
    }
    /**
  * Deletes this project. This is an irreversible operation.
  
  You cannot delete a project that still contains repositories.
  To delete the project, [delete](/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-delete)
  or transfer the repositories first.
  
  Example:
  ```
  $ curl -X DELETE https://api.bitbucket.org/2.0/workspaces/bbworkspace1/projects/PROJ
  ```
  * Alternative usage: Workspace.Project.deleteProject
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-projects/#api-workspaces-workspace-projects-project-key-delete
  * @param options Request options.
  */
    async deleteWorkspaceProject(options) {
        return this.Workspace.Project.deleteProject(options);
    }
    /**
     * Returns the requested project.
     * Alternative usage: Workspace.Project.getProject
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-projects/#api-workspaces-workspace-projects-project-key-get
     * @param options Request options.
     */
    async getWorkspaceProject(options) {
        return this.Workspace.Project.getProject(options);
    }
    /**
  * Search for code in the repositories of the specified workspace.
  
  Note that searches can match in the file's text (`content_matches`),
  the path (`path_matches`), or both.
  
  You can use the same syntax for the search query as in the UI.
  E.g. to search for "foo" only within the repository "demo",
  use the query parameter `search_query=foo+repo:demo`.
  
  Similar to other APIs, you can request more fields using a
  `fields` query parameter. E.g. to get some more information about
  the repository of matched files, use the query parameter
  `search_query=foo&fields=%2Bvalues.file.commit.repository`
  (the `%2B` is a URL-encoded `+`).
  
  Try `fields=%2Bvalues.*.*.*.*` to get an idea what's possible.
    
  * Alternative usage: Workspace.Project.Search.searchCodeInProjects
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-other-operations/#api-workspaces-workspace-search-code-get
  * @param options Request options.
  */
    async searchCodeInWorkspaceProjects(options) {
        return this.Workspace.Project.Search.searchCodeInProjects(options);
    }
    /**
     * Find workspace level variables.
     * Alternative usage: Workspace.Variable.getVariables
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-get
     * @param options Request options.
     */
    async getWorkspaceVariables(options) {
        return this.Workspace.Variable.getVariables(options);
    }
    /**
     * Create a workspace level variable.
     * Alternative usage: Workspace.Variable.createVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-post
     * @param options Request options.
     */
    async createWorkspaceVariable(options) {
        return this.Workspace.Variable.createVariable(options);
    }
    /**
     * Retrieve a workspace level variable.
     * Alternative usage: Workspace.Variable.getVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-variable-uuid-get
     * @param options Request options.
     */
    async getWorkspaceVariable(options) {
        return this.Workspace.Variable.getVariable(options);
    }
    /**
     * Update a workspace level variable.
     * Alternative usage: Workspace.Variable.updateVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-variable-uuid-put
     * @param options Request options.
     */
    async updateWorkspaceVariable(options) {
        return this.Workspace.Variable.updateVariable(options);
    }
    /**
     * Delete a workspace level variable.
     * Alternative usage: Workspace.Variable.deleteVariable
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-variable-uuid-delete
     * @param options Request options.
     */
    async deleteWorkspaceVariable(options) {
        return this.Workspace.Variable.deleteVariable(options);
    }
}
class RepositoryGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Pipeline = new RepositoryPipelineGroup(implementation, this.getGlobalErrorStrategy);
        this.Pullrequest = new RepositoryPullrequestGroup(implementation, this.getGlobalErrorStrategy);
        this.Branch = new RepositoryBranchGroup(implementation, this.getGlobalErrorStrategy);
        this.Commit = new RepositoryCommitGroup(implementation, this.getGlobalErrorStrategy);
        this.Reviewer = new RepositoryReviewerGroup(implementation, this.getGlobalErrorStrategy);
        this.Tag = new RepositoryTagGroup(implementation, this.getGlobalErrorStrategy);
        this.Environment = new RepositoryEnvironmentGroup(implementation, this.getGlobalErrorStrategy);
        this.Fork = new RepositoryForkGroup(implementation, this.getGlobalErrorStrategy);
        this.Deployment = new RepositoryDeploymentGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a paginated list of all public repositories.
  
  This endpoint also supports filtering and sorting of the results. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering) for more details.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-get
  * @param options Request options.
  */
    async getRepositories(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/2.0/repositories`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a paginated list of all repositories owned by the specified
  workspace.
  
  The result can be narrowed down based on the authenticated user's role.
  
  E.g. with `?role=contributor`, only those repositories that the
  authenticated user has write access to are returned (this includes any
  repo the user is an admin on, as that implies write access).
  
  This endpoint also supports filtering and sorting of the results. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering) for more details.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-get
  * @param options Request options.
  */
    async getRepositoriesByWorkspace(options) {
        const { headers, errorStrategy, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the object describing this repository.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-get
     * @param options Request options.
     */
    async getRepository(options) {
        const { headers, errorStrategy, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Since this endpoint can be used to both update and to create a
  repository, the request body depends on the intent.
  
  #### Creation
  
  See the POST documentation for the repository endpoint for an example
  of the request body.
  
  #### Update
  
  Note: Changing the `name` of the repository will cause the location to
  be changed. This is because the URL of the repo is derived from the
  name (a process called slugification). In such a scenario, it is
  possible for the request to fail if the newly created slug conflicts
  with an existing repository's slug. But if there is no conflict,
  the new location will be returned in the `Location` header of the
  response.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-put
  * @param options Request options.
  */
    async updateRepository(options) {
        const { body, headers, errorStrategy, repo_slug, workspace } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new repository.
  
  Note: In order to set the project for the newly created repository,
  pass in either the project key or the project UUID as part of the
  request body as shown in the examples below:
  
  ```
  $ curl -X POST -H "Content-Type: application/json" -d '{
      "scm": "git",
      "project": {
          "key": "MARS"
      }
  }' https://api.bitbucket.org/2.0/repositories/teamsinspace/hablanding
  ```
  
  or
  
  ```
  $ curl -X POST -H "Content-Type: application/json" -d '{
      "scm": "git",
      "project": {
          "key": "{ba516952-992a-4c2d-acbd-17d502922f96}"
      }
  }' https://api.bitbucket.org/2.0/repositories/teamsinspace/hablanding
  ```
  
  The project must be assigned for all repositories. If the project is not provided,
  the repository is automatically assigned to the oldest project in the workspace.
  
  Note: In the examples above, the workspace ID `teamsinspace`,
  and/or the repository name `hablanding` can be replaced by UUIDs.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-post
  * @param options Request options.
  */
    async createRepository(options) {
        const { body, headers, errorStrategy, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes the repository. This is an irreversible operation.
  
  This does not affect its forks.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-delete
  * @param options Request options.
  */
    async deleteRepository(options) {
        const { headers, errorStrategy, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the branches and tags in the repository.
  
  By default, results will be in the order the underlying source control system returns them and identical to
  the ordering one sees when running "$ git show-ref". Note that this follows simple
  lexical ordering of the ref names.
  
  This can be undesirable as it does apply any natural sorting semantics, meaning for instance that refs are
  sorted ["branch1", "branch10", "branch2", "v10", "v11", "v9"] instead of ["branch1", "branch2",
  "branch10", "v9", "v10", "v11"].
  
  Sorting can be changed using the ?sort= query parameter. When using ?sort=name to explicitly sort on ref name,
  Bitbucket will apply natural sorting and interpret numerical values as numbers instead of strings.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-get
  * @param options Request options.
  */
    async getBranchesAndTags(options) {
        const { headers, errorStrategy, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/refs`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryPipelineGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Step = new RepositoryPipelineStepGroup(implementation, this.getGlobalErrorStrategy);
        this.Configuration = new RepositoryPipelineConfigurationGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Endpoint to create and initiate a pipeline.
  There are a couple of different options to initiate a pipeline, where the payload of the request will determine which type of pipeline will be instantiated.
  # Trigger a Pipeline for a branch
  One way to trigger pipelines is by specifying the branch for which you want to trigger a pipeline.
  The specified branch will be used to determine which pipeline definition from the `bitbucket-pipelines.yml` file will be applied to initiate the pipeline. The pipeline will then do a clone of the repository and checkout the latest revision of the specified branch.
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/jeroendr/meat-demo2/pipelines/ \
    -d '
    {
      "target": {
        "ref_type": "branch",
        "type": "pipeline_ref_target",
        "ref_name": "master"
      }
    }'
  ```
  # Trigger a Pipeline for a commit on a branch or tag
  You can initiate a pipeline for a specific commit and in the context of a specified reference (e.g. a branch, tag or bookmark).
  The specified reference will be used to determine which pipeline definition from the bitbucket-pipelines.yml file will be applied to initiate the pipeline. The pipeline will clone the repository and then do a checkout the specified reference.
  
  The following reference types are supported:
  
  * `branch`
  * `named_branch`
  * `bookmark`
   * `tag`
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
    https://api.bitbucket.org/2.0/repositories/jeroendr/meat-demo2/pipelines/ \
    -d '
    {
      "target": {
        "commit": {
          "type": "commit",
          "hash": "ce5b7431602f7cbba007062eeb55225c6e18e956"
        },
        "ref_type": "branch",
        "type": "pipeline_ref_target",
        "ref_name": "master"
      }
    }'
  ```
  # Trigger a specific pipeline definition for a commit
  You can trigger a specific pipeline that is defined in your `bitbucket-pipelines.yml` file for a specific commit.
  In addition to the commit revision, you specify the type and pattern of the selector that identifies the pipeline definition. The resulting pipeline will then clone the repository and checkout the specified revision.
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/jeroendr/meat-demo2/pipelines/ \
   -d '
    {
       "target": {
        "commit": {
           "hash":"a3c4e02c9a3755eccdc3764e6ea13facdf30f923",
           "type":"commit"
         },
          "selector": {
             "type":"custom",
                "pattern":"Deploy to production"
            },
          "type":"pipeline_commit_target"
     }
    }'
  ```
  # Trigger a specific pipeline definition for a commit on a branch or tag
  You can trigger a specific pipeline that is defined in your `bitbucket-pipelines.yml` file for a specific commit in the context of a specified reference.
  In addition to the commit revision, you specify the type and pattern of the selector that identifies the pipeline definition, as well as the reference information. The resulting pipeline will then clone the repository a checkout the specified reference.
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/jeroendr/meat-demo2/pipelines/ \
   -d '
    {
       "target": {
        "commit": {
           "hash":"a3c4e02c9a3755eccdc3764e6ea13facdf30f923",
           "type":"commit"
         },
         "selector": {
            "type": "custom",
            "pattern": "Deploy to production"
         },
         "type": "pipeline_ref_target",
         "ref_name": "master",
         "ref_type": "branch"
       }
    }'
  ```
  
  
  # Trigger a custom pipeline with variables
  In addition to triggering a custom pipeline that is defined in your `bitbucket-pipelines.yml` file as shown in the examples above, you can specify variables that will be available for your build. In the request, provide a list of variables, specifying the following for each variable: key, value, and whether it should be secured or not (this field is optional and defaults to not secured).
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/{workspace}/{repo_slug}/pipelines/ \
   -d '
    {
      "target": {
        "type": "pipeline_ref_target",
        "ref_type": "branch",
        "ref_name": "master",
        "selector": {
          "type": "custom",
          "pattern": "Deploy to production"
        }
      },
      "variables": [
        {
          "key": "var1key",
          "value": "var1value",
          "secured": true
        },
        {
          "key": "var2key",
          "value": "var2value"
        }
      ]
    }'
  ```
  
  # Trigger a pull request pipeline
  
  You can also initiate a pipeline for a specific pull request.
  
  ### Example
  
  ```
  $ curl -X POST -is -u username:password \
    -H 'Content-Type: application/json' \
   https://api.bitbucket.org/2.0/repositories/{workspace}/{repo_slug}/pipelines/ \
   -d '
    {
      "target": {
        "type": "pipeline_pullrequest_target",
        "source": "pull-request-branch",
        "destination": "master",
        "destination_commit": {
          "hash": "9f848b7"
        },
        "commit": {
          "hash": "1a372fc"
        },
        "pullrequest": {
          "id": "3"
        },
        "selector": {
          "type": "pull-requests",
          "pattern": "**"
        }
      }
    }'
  ```
    
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-post
  * @param options Request options.
  */
    async createAndInitiatePipeline(options) {
        const { body, headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Find pipelines in a repository.
  
  Note that unlike other endpoints in the Bitbucket API, this endpoint utilizes query parameters to allow filtering
  and sorting of returned results. See [query parameters](#api-repositories-workspace-repo-slug-pipelines-get-request-Query%20parameters)
  for specific details.
    
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-get
  * @param options Request options.
  */
    async findPipelines(options) {
        const { headers, errorStrategy, workspace, repo_slug, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a specified pipeline
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-get
     * @param options Request options.
     */
    async retrievePipeline(options) {
        const { headers, errorStrategy, workspace, repo_slug, pipeline_uuid } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines/${encodeURIComponent(pipeline_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Signal the stop of a pipeline and all of its steps that not have completed yet.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-pipeline-uuid-stoppipeline-post
     * @param options Request options.
     */
    async stopPipeline(options) {
        const { headers, errorStrategy, workspace, repo_slug, pipeline_uuid } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines/${encodeURIComponent(pipeline_uuid)}/stopPipeline`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryPipelineStepGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Find steps for the given pipeline.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-pipeline-uuid-steps-get
     * @param options Request options.
     */
    async findSteps(options) {
        const { headers, errorStrategy, workspace, repo_slug, pipeline_uuid } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines/${encodeURIComponent(pipeline_uuid)}/steps`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a given step of a pipeline.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-pipeline-uuid-steps-step-uuid-get
     * @param options Request options.
     */
    async retrieveStep(options) {
        const { headers, errorStrategy, workspace, repo_slug, pipeline_uuid, step_uuid } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines/${encodeURIComponent(pipeline_uuid)}/steps/${encodeURIComponent(step_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryPipelineConfigurationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Build = new RepositoryPipelineConfigurationBuildGroup(implementation, this.getGlobalErrorStrategy);
        this.Schedule = new RepositoryPipelineConfigurationScheduleGroup(implementation, this.getGlobalErrorStrategy);
        this.Variable = new RepositoryPipelineConfigurationVariableGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Update the pipelines configuration for a repository.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-put
     * @param options Request options.
     */
    async updateConfiguration(options) {
        const { body, headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve the repository pipelines configuration.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-get
     * @param options Request options.
     */
    async retrieveConfiguration(options) {
        const { headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryPipelineConfigurationBuildGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Update the next build number that should be assigned to a pipeline. The next build number that will be configured has to be strictly higher than the current latest build number for this repository.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-build-number-put
     * @param options Request options.
     */
    async updateBuildNumber(options) {
        const { body, headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/build_number`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryPipelineConfigurationScheduleGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Create a schedule for the given repository.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-post
     * @param options Request options.
     */
    async createSchedule(options) {
        const { body, headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/schedules`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve the configured schedules for the given repository.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-get
     * @param options Request options.
     */
    async retrieveSchedules(options) {
        const { headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/schedules`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update a schedule.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-schedule-uuid-put
     * @param options Request options.
     */
    async updateSchedule(options) {
        const { body, headers, errorStrategy, workspace, repo_slug, schedule_uuid } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/schedules/${encodeURIComponent(schedule_uuid)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a schedule by its UUID.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-schedule-uuid-get
     * @param options Request options.
     */
    async retrieveSchedule(options) {
        const { headers, errorStrategy, workspace, repo_slug, schedule_uuid } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/schedules/${encodeURIComponent(schedule_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete a schedule.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-schedules-schedule-uuid-delete
     * @param options Request options.
     */
    async deleteSchedule(options) {
        const { headers, errorStrategy, workspace, repo_slug, schedule_uuid } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/schedules/${encodeURIComponent(schedule_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryPipelineConfigurationVariableGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Find repository level variables.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-get
     * @param options Request options.
     */
    async getVariables(options) {
        const { headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/variables`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a repository level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-post
     * @param options Request options.
     */
    async createVariable(options) {
        const { body, headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/variables`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a repository level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-variable-uuid-get
     * @param options Request options.
     */
    async getVariable(options) {
        const { headers, errorStrategy, workspace, repo_slug, variable_uuid } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/variables/${encodeURIComponent(variable_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update a repository level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-variable-uuid-put
     * @param options Request options.
     */
    async updateVariable(options) {
        const { body, headers, errorStrategy, workspace, repo_slug, variable_uuid } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/variables/${encodeURIComponent(variable_uuid)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete a repository level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-pipelines-config-variables-variable-uuid-delete
     * @param options Request options.
     */
    async deleteVariable(options) {
        const { headers, errorStrategy, workspace, repo_slug, variable_uuid } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pipelines_config/variables/${encodeURIComponent(variable_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryPullrequestGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Comment = new RepositoryPullrequestCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.Commit = new RepositoryPullrequestCommitGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all pull requests on the specified repository.
  
  By default only open pull requests are returned. This can be controlled
  using the `state` query parameter. To retrieve pull requests that are
  in one of multiple states, repeat the `state` parameter for each
  individual state.
  
  This endpoint also supports filtering and sorting of the results. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering) for more details.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-get
  * @param options Request options.
  */
    async getPullrequests(options) {
        const { headers, errorStrategy, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new pull request where the destination repository is
  this repository and the author is the authenticated user.
  
  The minimum required fields to create a pull request are `title` and
  `source`, specified by a branch name.
  
  ```
  curl https://api.bitbucket.org/2.0/repositories/my-workspace/my-repository/pullrequests \
      -u my-username:my-password \
      --request POST \
      --header 'Content-Type: application/json' \
      --data '{
          "title": "My Title",
          "source": {
              "branch": {
                  "name": "staging"
              }
          }
      }'
  ```
  
  If the pull request's `destination` is not specified, it will default
  to the `repository.mainbranch`. To open a pull request to a
  different branch, say from a feature branch to a staging branch,
  specify a `destination` (same format as the `source`):
  
  ```
  {
      "title": "My Title",
      "source": {
          "branch": {
              "name": "my-feature-branch"
          }
      },
      "destination": {
          "branch": {
              "name": "staging"
          }
      }
  }
  ```
  
  Reviewers can be specified by adding an array of user objects as the
  `reviewers` property.
  
  ```
  {
      "title": "My Title",
      "source": {
          "branch": {
              "name": "my-feature-branch"
          }
      },
      "reviewers": [
          {
              "uuid": "{504c3b62-8120-4f0c-a7bc-87800b9d6f70}"
          }
      ]
  }
  ```
  
  Other fields:
  
  * `description` - a string
  * `close_source_branch` - boolean that specifies if the source branch should be closed upon merging
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-post
  * @param options Request options.
  */
    async createPullrequest(options) {
        const { body, headers, errorStrategy, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a paginated list of the pull request's activity log.
  
  This handler serves both a v20 and internal endpoint. The v20 endpoint
  returns reviewer comments, updates, approvals and request changes. The internal
  endpoint includes those plus tasks and attachments.
  
  Comments created on a file or a line of code have an inline property.
  
  Comment example:
  ```
  {
      "pagelen": 20,
      "values": [
          {
              "comment": {
                  "links": {
                      "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695/comments/118571088"
                      },
                      "html": {
                          "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695/_/diff#comment-118571088"
                      }
                  },
                  "deleted": false,
                  "pullrequest": {
                      "type": "pullrequest",
                      "id": 5695,
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                          },
                          "html": {
                              "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                          }
                      },
                      "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
                  },
                  "content": {
                      "raw": "inline with to a dn from lines",
                      "markup": "markdown",
                      "html": "<p>inline with to a dn from lines</p>",
                      "type": "rendered"
                  },
                  "created_on": "2019-09-27T00:33:46.039178+00:00",
                  "user": {
                      "display_name": "Name Lastname",
                      "uuid": "{}",
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/users/%7B%7D"
                          },
                          "html": {
                              "href": "https://bitbucket.org/%7B%7D/"
                          },
                          "avatar": {
                              "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/:/128"
                          }
                      },
                      "type": "user",
                      "nickname": "Name",
                      "account_id": ""
                  },
                  "created_on": "2019-09-27T00:33:46.039178+00:00",
                  "user": {
                      "display_name": "Name Lastname",
                      "uuid": "{}",
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/users/%7B%7D"
                          },
                          "html": {
                              "href": "https://bitbucket.org/%7B%7D/"
                          },
                          "avatar": {
                              "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/:/128"
                          }
                      },
                      "type": "user",
                      "nickname": "Name",
                      "account_id": ""
                  },
                  "updated_on": "2019-09-27T00:33:46.055384+00:00",
                  "inline": {
                      "context_lines": "",
                      "to": null,
                      "path": "",
                      "outdated": false,
                      "from": 211
                  },
                  "type": "pullrequest_comment",
                  "id": 118571088
              },
              "pull_request": {
                  "type": "pullrequest",
                  "id": 5695,
                  "links": {
                      "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                      },
                      "html": {
                          "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                      }
                  },
                  "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
              }
          }
      ]
  }
  ```
  
  Updates include a state property of OPEN, MERGED, or DECLINED.
  
  Update example:
  ```
  {
      "pagelen": 20,
      "values": [
          {
              "update": {
                  "description": "",
                  "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it",
                  "destination": {
                      "commit": {
                          "type": "commit",
                          "hash": "6a2c16e4a152",
                          "links": {
                              "self": {
                                  "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/commit/6a2c16e4a152"
                              },
                              "html": {
                                  "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/commits/6a2c16e4a152"
                              }
                          }
                      },
                      "branch": {
                          "name": "master"
                      },
                      "repository": {
                          "name": "Atlaskit-MK-2",
                          "type": "repository",
                          "full_name": "atlassian/atlaskit-mk-2",
                          "links": {
                              "self": {
                                  "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2"
                              },
                              "html": {
                                  "href": "https://bitbucket.org/atlassian/atlaskit-mk-2"
                              },
                              "avatar": {
                                  "href": "https://bytebucket.org/ravatar/%7B%7D?ts=js"
                              }
                          },
                          "uuid": "{}"
                      }
                  },
                  "reason": "",
                  "source": {
                      "commit": {
                          "type": "commit",
                          "hash": "728c8bad1813",
                          "links": {
                              "self": {
                                  "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/commit/728c8bad1813"
                              },
                              "html": {
                                  "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/commits/728c8bad1813"
                              }
                          }
                      },
                      "branch": {
                          "name": "username/NONE-add-onClick-prop-for-accessibility"
                      },
                      "repository": {
                          "name": "Atlaskit-MK-2",
                          "type": "repository",
                          "full_name": "atlassian/atlaskit-mk-2",
                          "links": {
                              "self": {
                                  "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2"
                              },
                              "html": {
                                  "href": "https://bitbucket.org/atlassian/atlaskit-mk-2"
                              },
                              "avatar": {
                                  "href": "https://bytebucket.org/ravatar/%7B%7D?ts=js"
                              }
                          },
                          "uuid": "{}"
                      }
                  },
                  "state": "OPEN",
                  "author": {
                      "display_name": "Name Lastname",
                      "uuid": "{}",
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/users/%7B%7D"
                          },
                          "html": {
                              "href": "https://bitbucket.org/%7B%7D/"
                          },
                          "avatar": {
                              "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/:/128"
                          }
                      },
                      "type": "user",
                      "nickname": "Name",
                      "account_id": ""
                  },
                  "date": "2019-05-10T06:48:25.305565+00:00"
              },
              "pull_request": {
                  "type": "pullrequest",
                  "id": 5695,
                  "links": {
                      "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                      },
                      "html": {
                          "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                      }
                  },
                  "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
              }
          }
      ]
  }
  ```
  
  Approval example:
  ```
  {
      "pagelen": 20,
      "values": [
          {
              "approval": {
                  "date": "2019-09-27T00:37:19.849534+00:00",
                  "pullrequest": {
                      "type": "pullrequest",
                      "id": 5695,
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                          },
                          "html": {
                              "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                          }
                      },
                      "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
                  },
                  "user": {
                      "display_name": "Name Lastname",
                      "uuid": "{}",
                      "links": {
                          "self": {
                              "href": "https://api.bitbucket.org/2.0/users/%7B%7D"
                          },
                          "html": {
                              "href": "https://bitbucket.org/%7B%7D/"
                          },
                          "avatar": {
                              "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/:/128"
                          }
                      },
                      "type": "user",
                      "nickname": "Name",
                      "account_id": ""
                  }
              },
              "pull_request": {
                  "type": "pullrequest",
                  "id": 5695,
                  "links": {
                      "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/atlaskit-mk-2/pullrequests/5695"
                      },
                      "html": {
                          "href": "https://bitbucket.org/atlassian/atlaskit-mk-2/pull-requests/5695"
                      }
                  },
                  "title": "username/NONE: small change from onFocus to onClick to handle tabbing through the page and not expand the editor unless a click event triggers it"
              }
          }
      ]
  }
  ```
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-activity-get
  * @param options Request options.
  */
    async getActivityLog(options) {
        const { headers, errorStrategy, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/activity`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the specified pull request.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-get
     * @param options Request options.
     */
    async getPullrequest(options) {
        const { headers, errorStrategy, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Mutates the specified pull request.
  
  This can be used to change the pull request's branches or description.
  
  Only open pull requests can be mutated.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-put
  * @param options Request options.
  */
    async mutatePullrequest(options) {
        const { body, headers, errorStrategy, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Approve the specified pull request as the authenticated user.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-approve-post
     * @param options Request options.
     */
    async approvePullrequest(options) {
        const { headers, errorStrategy, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/approve`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Declines the pull request.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-decline-post
     * @param options Request options.
     */
    async declinePullrequest(options) {
        const { headers, errorStrategy, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/decline`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Merges the pull request.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-merge-post
     * @param options Request options.
     */
    async mergePullrequest(options) {
        const { body, headers, errorStrategy, pull_request_id, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/merge`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all statuses (e.g. build results) for the given pull
  request.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-statuses-get
  * @param options Request options.
  */
    async getPullrequestStatuses(options) {
        const { headers, errorStrategy, pull_request_id, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/statuses`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryPullrequestCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a paginated list of the pull request's comments.
  
  This includes both global, inline comments and replies.
  
  The default sorting is oldest to newest and can be overridden with
  the `sort` query parameter.
  
  This endpoint also supports filtering and sorting of the results. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering) for more
  details.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/comments`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new pull request comment.
  
  Returns the newly created pull request comment.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-post
  * @param options Request options.
  */
    async createComment(options) {
        const { body, headers, errorStrategy, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/comments`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes a specific pull request comment.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-comment-id-delete
     * @param options Request options.
     */
    async deleteComment(options) {
        const { headers, errorStrategy, comment_id, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/comments/${encodeURIComponent(comment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Returns a specific pull request comment.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-comment-id-get
     * @param options Request options.
     */
    async getComment(options) {
        const { headers, errorStrategy, comment_id, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/comments/${encodeURIComponent(comment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates a specific pull request comment.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-comments-comment-id-put
     * @param options Request options.
     */
    async updateComment(options) {
        const { body, headers, errorStrategy, comment_id, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/comments/${encodeURIComponent(comment_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryPullrequestCommitGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a paginated list of the pull request's commits.
  
  These are the commits that are being merged into the destination
  branch when the pull requests gets accepted.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-pullrequests-pull-request-id-commits-get
  * @param options Request options.
  */
    async getCommits(options) {
        const { headers, errorStrategy, pull_request_id, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/pullrequests/${encodeURIComponent(pull_request_id)}/commits`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryBranchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Restriction = new RepositoryBranchRestrictionGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a list of all open branches within the specified repository.
   Results will be in the order the source control manager returns them.
  
          ```
          $ curl -s https://api.bitbucket.org/2.0/repositories/atlassian/aui/refs/branches?pagelen=1 | jq .
          {
            "pagelen": 1,
            "size": 187,
            "values": [
              {
                "name": "issue-9.3/AUI-5343-assistive-class",
                "links": {
                  "commits": {
                    "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commits/issue-9.3/AUI-5343-assistive-class"
                  },
                  "self": {
                    "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/refs/branches/issue-9.3/AUI-5343-assistive-class"
                  },
                  "html": {
                    "href": "https://bitbucket.org/atlassian/aui/branch/issue-9.3/AUI-5343-assistive-class"
                  }
                },
                "default_merge_strategy": "squash",
                "merge_strategies": [
                  "merge_commit",
                  "squash",
                  "fast_forward"
                ],
                "type": "branch",
                "target": {
                  "hash": "e5d1cde9069fcb9f0af90403a4de2150c125a148",
                  "repository": {
                    "links": {
                      "self": {
                        "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui"
                      },
                      "html": {
                        "href": "https://bitbucket.org/atlassian/aui"
                      },
                      "avatar": {
                        "href": "https://bytebucket.org/ravatar/%7B585074de-7b60-4fd1-81ed-e0bc7fafbda5%7D?ts=86317"
                      }
                    },
                    "type": "repository",
                    "name": "aui",
                    "full_name": "atlassian/aui",
                    "uuid": "{585074de-7b60-4fd1-81ed-e0bc7fafbda5}"
                  },
                  "links": {
                    "self": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/e5d1cde9069fcb9f0af90403a4de2150c125a148"
                    },
                    "comments": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/e5d1cde9069fcb9f0af90403a4de2150c125a148/comments"
                    },
                    "patch": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/patch/e5d1cde9069fcb9f0af90403a4de2150c125a148"
                    },
                    "html": {
                      "href": "https://bitbucket.org/atlassian/aui/commits/e5d1cde9069fcb9f0af90403a4de2150c125a148"
                    },
                    "diff": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/diff/e5d1cde9069fcb9f0af90403a4de2150c125a148"
                    },
                    "approve": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/e5d1cde9069fcb9f0af90403a4de2150c125a148/approve"
                    },
                    "statuses": {
                      "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/e5d1cde9069fcb9f0af90403a4de2150c125a148/statuses"
                    }
                  },
                  "author": {
                    "raw": "Marcin Konopka <mkonopka@atlassian.com>",
                    "type": "author",
                    "user": {
                      "display_name": "Marcin Konopka",
                      "uuid": "{47cc24f4-2a05-4420-88fe-0417535a110a}",
                      "links": {
                        "self": {
                          "href": "https://api.bitbucket.org/2.0/users/%7B47cc24f4-2a05-4420-88fe-0417535a110a%7D"
                        },
                        "html": {
                          "href": "https://bitbucket.org/%7B47cc24f4-2a05-4420-88fe-0417535a110a%7D/"
                        },
                        "avatar": {
                          "href": "https://avatar-management--avatars.us-west-2.prod.public.atl-paas.net/initials/MK-1.png"
                        }
                      },
                      "nickname": "Marcin Konopka",
                      "type": "user",
                      "account_id": "60113d2b47a9540069f4de03"
                    }
                  },
                  "parents": [
                    {
                      "hash": "87f7fc92b00464ae47b13ef65c91884e4ac9be51",
                      "type": "commit",
                      "links": {
                        "self": {
                          "href": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/commit/87f7fc92b00464ae47b13ef65c91884e4ac9be51"
                        },
                        "html": {
                          "href": "https://bitbucket.org/atlassian/aui/commits/87f7fc92b00464ae47b13ef65c91884e4ac9be51"
                        }
                      }
                    }
                  ],
                  "date": "2021-04-13T13:44:49+00:00",
                  "message": "wip
  ",
                  "type": "commit"
                }
              }
            ],
            "page": 1,
            "next": "https://api.bitbucket.org/2.0/repositories/atlassian/aui/refs/branches?pagelen=1&page=2"
          }
          ```
  
          Branches support [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering)
          that can be used to search for specific branches. For instance, to find
          all branches that have "stab" in their name:
  
          ```
          curl -s https://api.bitbucket.org/2.0/repositories/atlassian/aui/refs/branches -G --data-urlencode 'q=name ~ "stab"'
          ```
  
          By default, results will be in the order the underlying source control system returns them and identical to
          the ordering one sees when running "$ git branch --list". Note that this follows simple
          lexical ordering of the ref names.
  
          This can be undesirable as it does apply any natural sorting semantics, meaning for instance that tags are
          sorted ["v10", "v11", "v9"] instead of ["v9", "v10", "v11"].
  
          Sorting can be changed using the ?q= query parameter. When using ?q=name to explicitly sort on ref name,
          Bitbucket will apply natural sorting and interpret numerical values as numbers instead of strings.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-branches-get
  * @param options Request options.
  */
    async getOpenBranches(options) {
        const { headers, errorStrategy, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/refs/branches`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new branch in the specified repository.
  
  The payload of the POST should consist of a JSON document that
  contains the name of the tag and the target hash.
  
  ```
  curl https://api.bitbucket.org/2.0/repositories/seanfarley/hg/refs/branches \
  -s -u seanfarley -X POST -H "Content-Type: application/json" \
  -d '{
      "name" : "smf/create-feature",
      "target" : {
          "hash" : "default",
      }
  }'
  ```
  
  This call requires authentication. Private repositories require the
  caller to authenticate with an account that has appropriate
  authorization.
  
  The branch name should not include any prefixes (e.g.
  refs/heads). This endpoint does support using short hash prefixes for
  the commit hash, but it may return a 400 response if the provided
  prefix is ambiguous. Using a full commit hash is the preferred
  approach.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-branches-post
  * @param options Request options.
  */
    async createBranch(options) {
        const { headers, errorStrategy, repo_slug, workspace, body } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/refs/branches`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a branch object within the specified repository.
  
  This call requires authentication. Private repositories require the
  caller to authenticate with an account that has appropriate
  authorization.
  
  For Git, the branch name should not include any prefixes (e.g.
  refs/heads).
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-branches-name-get
  * @param options Request options.
  */
    async getBranch(options) {
        const { headers, errorStrategy, name, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/refs/branches/${encodeURIComponent(name)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a branch in the specified repository.
  
  The main branch is not allowed to be deleted and will return a 400
  response.
  
  The branch name should not include any prefixes (e.g.
  refs/heads).
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-branches-name-delete
  * @param options Request options.
  */
    async deleteBranch(options) {
        const { headers, errorStrategy, name, repo_slug, workspace } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/refs/branches/${encodeURIComponent(name)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryBranchRestrictionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a paginated list of all branch restrictions on the
  repository.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-group-branch-restrictions
  * @param options Request options.
  */
    async getRestrictions(options) {
        const { headers, errorStrategy, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/branch-restrictions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new branch restriction rule for a repository.
  
  `kind` describes what will be restricted. Allowed values include:
  `push`, `force`, `delete`, `restrict_merges`, `require_tasks_to_be_completed`,
  `require_approvals_to_merge`, `require_default_reviewer_approvals_to_merge`,
  `require_no_changes_requested`, `require_passing_builds_to_merge`, `require_commits_behind`,
  `reset_pullrequest_approvals_on_change`, `smart_reset_pullrequest_approvals`,
  `reset_pullrequest_changes_requested_on_change`, `require_all_dependencies_merged`,
  `enforce_merge_checks`, and `allow_auto_merge_when_builds_pass`.
  
  Different kinds of branch restrictions have different requirements:
  
  * `push` and `restrict_merges` require `users` and `groups` to be
    specified. Empty lists are allowed, in which case permission is
    denied for everybody.
  
  The restriction applies to all branches that match. There are
  two ways to match a branch. It is configured in `branch_match_kind`:
  
  1. `glob`: Matches a branch against the `pattern`. A `'*'` in
     `pattern` will expand to match zero or more characters, and every
     other character matches itself. For example, `'foo*'` will match
     `'foo'` and `'foobar'`, but not `'barfoo'`. `'*'` will match all
     branches.
  2. `branching_model`: Matches a branch against the repository's
     branching model. The `branch_type` controls the type of branch
     to match. Allowed values include: `production`, `development`,
     `bugfix`, `release`, `feature` and `hotfix`.
  
  The combination of `kind` and match must be unique. This means that
  two `glob` restrictions in a repository cannot have the same `kind` and
  `pattern`. Additionally, two `branching_model` restrictions in a
  repository cannot have the same `kind` and `branch_type`.
  
  `users` and `groups` are lists of users and groups that are except from
  the restriction. They can only be configured in `push` and
  `restrict_merges` restrictions. The `push` restriction stops a user
  pushing to matching branches unless that user is in `users` or is a
  member of a group in `groups`. The `restrict_merges` stops a user
  merging pull requests to matching branches unless that user is in
  `users` or is a member of a group in `groups`. Adding new users or
  groups to an existing restriction should be done via `PUT`.
  
  Note that branch restrictions with overlapping matchers is allowed,
  but the resulting behavior may be surprising.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-post
  * @param options Request options.
  */
    async createRestriction(options) {
        const { body, headers, errorStrategy, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/branch-restrictions`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a specific branch restriction rule.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-id-get
     * @param options Request options.
     */
    async getRestriction(options) {
        const { headers, errorStrategy, id, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/branch-restrictions/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates an existing branch restriction rule.
  
  Fields not present in the request body are ignored.
  
  See [`POST`](/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-post) for details.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-id-put
  * @param options Request options.
  */
    async updateRestriction(options) {
        const { body, headers, errorStrategy, id, repo_slug, workspace } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/branch-restrictions/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes an existing branch restriction rule.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-branch-restrictions/#api-repositories-workspace-repo-slug-branch-restrictions-id-delete
     * @param options Request options.
     */
    async deleteRestriction(options) {
        const { headers, errorStrategy, id, repo_slug, workspace } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/branch-restrictions/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryCommitGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Approval = new RepositoryCommitApprovalGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new RepositoryCommitCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.Status = new RepositoryCommitStatusGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Returns the specified commit.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-get
     * @param options Request options.
     */
    async getCommit(options) {
        const { headers, errorStrategy, commit, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/commit/${encodeURIComponent(commit)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a paginated list of commits that modified the specified file.
  
  Commits are returned in reverse chronological order. This is roughly
  equivalent to the following commands:
  
      $ git log --follow --date-order <sha> <path>
  
  By default, Bitbucket will follow renames and the path name in the
  returned entries reflects that. This can be turned off using the
  `?renames=false` query parameter.
  
  Results are returned in descending chronological order by default, and
  like most endpoints you can
  [filter and sort](/cloud/bitbucket/rest/intro/#filtering) the response to
  only provide exactly the data you want.
  
  For example, if you wanted to find commits made before 2011-05-18
  against a file named `README.rst`, but you only wanted the path and
  date, your query would look like this:
  
  ```
  $ curl 'https://api.bitbucket.org/2.0/repositories/evzijst/dogslow/filehistory/master/README.rst'\
    '?fields=values.next,values.path,values.commit.date&q=commit.date<=2011-05-18'
  {
    "values": [
      {
        "commit": {
          "date": "2011-05-17T07:32:09+00:00"
        },
        "path": "README.rst"
      },
      {
        "commit": {
          "date": "2011-05-16T06:33:28+00:00"
        },
        "path": "README.txt"
      },
      {
        "commit": {
          "date": "2011-05-16T06:15:39+00:00"
        },
        "path": "README.txt"
      }
    ]
  }
  ```
  
  In the response you can see that the file was renamed to `README.rst`
  by the commit made on 2011-05-16, and was previously named `README.txt`.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-source/#api-repositories-workspace-repo-slug-filehistory-commit-path-get
  * @param options Request options.
  */
    async getCommitsByFile(options) {
        const { headers, errorStrategy, branch, path, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/filehistory/${encodeURIComponent(branch)}/${encodeURIComponent(path)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Identical to `GET /repositories/{workspace}/{repo_slug}/commits`,
  except that POST allows clients to place the include and exclude
  parameters in the request body to avoid URL length issues.
  
  **Note that this resource does NOT support new commit creation.**
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commits-post
  * @param options Request options.
  */
    async getCommits(options) {
        const { body, headers, errorStrategy, repo_slug, workspace } = options;
        const requestBody = body ? URLEncodeBodyWithDuplicateValues(body).toString() : body;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/commits`, constructHeaders(requestBody, { ...headers, "Content-Type": "application/x-www-form-urlencoded" }), requestBody);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryCommitApprovalGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Approve the specified commit as the authenticated user.
  
  This operation is only available to users that have explicit access to
  the repository. In contrast, just the fact that a repository is
  publicly accessible to users does not give them the ability to approve
  commits.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-approve-post
  * @param options Request options.
  */
    async approveCommit(options) {
        const { headers, errorStrategy, commit, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/commit/${encodeURIComponent(commit)}/approve`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Redact the authenticated user's approval of the specified commit.
  
  This operation is only available to users that have explicit access to
  the repository. In contrast, just the fact that a repository is
  publicly accessible to users does not give them the ability to approve
  commits.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-approve-delete
  * @param options Request options.
  */
    async redactApproval(options) {
        const { headers, errorStrategy, commit, repo_slug, workspace } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/commit/${encodeURIComponent(commit)}/approve`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryCommitCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the commit's comments.
  
  This includes both global and inline comments.
  
  The default sorting is oldest to newest and can be overridden with
  the `sort` query parameter.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-comments-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, commit, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/commit/${encodeURIComponent(commit)}/comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the specified commit comment.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commits/#api-repositories-workspace-repo-slug-commit-commit-comments-comment-id-get
     * @param options Request options.
     */
    async getComment(options) {
        const { headers, errorStrategy, comment_id, commit, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/commit/${encodeURIComponent(commit)}/comments/${encodeURIComponent(comment_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryCommitStatusGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns all statuses (e.g. build results) for a specific commit.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commit-statuses/#api-repositories-workspace-repo-slug-commit-commit-statuses-get
     * @param options Request options.
     */
    async getStatuses(options) {
        const { headers, errorStrategy, commit, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/commit/${encodeURIComponent(commit)}/statuses`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new build status against the specified commit.
  
  If the specified key already exists, the existing status object will
  be overwritten.
  
  Example:
  
  ```
  curl https://api.bitbucket.org/2.0/repositories/my-workspace/my-repo/commit/e10dae226959c2194f2b07b077c07762d93821cf/statuses/build/           -X POST -u jdoe -H 'Content-Type: application/json'           -d '{
      "key": "MY-BUILD",
      "state": "SUCCESSFUL",
      "description": "42 tests passed",
      "url": "https://www.example.org/my-build-result"
    }'
  ```
  
  When creating a new commit status, you can use a URI template for the URL.
  Templates are URLs that contain variable names that Bitbucket will
  evaluate at runtime whenever the URL is displayed anywhere similar to
  parameter substitution in
  [Bitbucket Connect](https://developer.atlassian.com/bitbucket/concepts/context-parameters.html).
  For example, one could use `https://foo.com/builds/{repository.full_name}`
  which Bitbucket will turn into `https://foo.com/builds/foo/bar` at render time.
  The context variables available are `repository` and `commit`.
  
  To associate a commit status to a pull request, the refname field must be set to the source branch
  of the pull request.
  
  Example:
  ```
  curl https://api.bitbucket.org/2.0/repositories/my-workspace/my-repo/commit/e10dae226959c2194f2b07b077c07762d93821cf/statuses/build/           -X POST -u jdoe -H 'Content-Type: application/json'           -d '{
      "key": "MY-BUILD",
      "state": "SUCCESSFUL",
      "description": "42 tests passed",
      "url": "https://www.example.org/my-build-result",
      "refname": "my-pr-branch"
    }'
  ```
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commit-statuses/#api-repositories-workspace-repo-slug-commit-commit-statuses-build-post
  * @param options Request options.
  */
    async createStatus(options) {
        const { body, headers, errorStrategy, commit, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/commit/${encodeURIComponent(commit)}/statuses/build`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the specified build status for a commit.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-commit-statuses/#api-repositories-workspace-repo-slug-commit-commit-statuses-build-key-get
     * @param options Request options.
     */
    async getStatus(options) {
        const { headers, errorStrategy, commit, key, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/commit/${encodeURIComponent(commit)}/statuses/build/${encodeURIComponent(key)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryReviewerGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Default = new RepositoryReviewerDefaultGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class RepositoryReviewerDefaultGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the repository's default reviewers.
  
  These are the users that are automatically added as reviewers on every
  new pull request that is created. To obtain the repository's default reviewers
  as well as the default reviewers inherited from the project, use the
  [effective-default-reveiwers](#api-repositories-workspace-repo-slug-effective-default-reviewers-get) endpoint.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-default-reviewers-get
  * @param options Request options.
  */
    async getReviewers(options) {
        const { headers, errorStrategy, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/default-reviewers`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the specified reviewer.
  
  This can be used to test whether a user is among the repository's
  default reviewers list. A 404 indicates that that specified user is not
  a default reviewer.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-default-reviewers-target-username-get
  * @param options Request options.
  */
    async getReviewer(options) {
        const { headers, errorStrategy, repo_slug, target_username, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/default-reviewers/${encodeURIComponent(target_username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds the specified user to the repository's list of default
  reviewers.
  
  This method is idempotent. Adding a user a second time has no effect.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-default-reviewers-target-username-put
  * @param options Request options.
  */
    async addReviewer(options) {
        const { headers, errorStrategy, repo_slug, target_username, workspace } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/default-reviewers/${encodeURIComponent(target_username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Removes a default reviewer from the repository.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pullrequests/#api-repositories-workspace-repo-slug-default-reviewers-target-username-delete
     * @param options Request options.
     */
    async removeReviewer(options) {
        const { headers, errorStrategy, repo_slug, target_username, workspace } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/default-reviewers/${encodeURIComponent(target_username)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryTagGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the tags in the repository.
  
  By default, results will be in the order the underlying source control system returns them and identical to
  the ordering one sees when running "$ git tag --list". Note that this follows simple
  lexical ordering of the ref names.
  
  This can be undesirable as it does apply any natural sorting semantics, meaning for instance that tags are
  sorted ["v10", "v11", "v9"] instead of ["v9", "v10", "v11"].
  
  Sorting can be changed using the ?sort= query parameter. When using ?sort=name to explicitly sort on ref name,
  Bitbucket will apply natural sorting and interpret numerical values as numbers instead of strings.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-tags-get
  * @param options Request options.
  */
    async getTags(options) {
        const { headers, errorStrategy, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/refs/tags`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new tag in the specified repository.
  
  The payload of the POST should consist of a JSON document that
  contains the name of the tag and the target hash.
  
  ```
  curl https://api.bitbucket.org/2.0/repositories/jdoe/myrepo/refs/tags \
  -s -u jdoe -X POST -H "Content-Type: application/json" \
  -d '{
      "name" : "new-tag-name",
      "target" : {
          "hash" : "a1b2c3d4e5f6",
      }
  }'
  ```
  
  This endpoint does support using short hash prefixes for the commit
  hash, but it may return a 400 response if the provided prefix is
  ambiguous. Using a full commit hash is the preferred approach.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-tags-post
  * @param options Request options.
  */
    async createTag(options) {
        const { body, headers, errorStrategy, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/refs/tags`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the specified tag.
  
  ```
  $ curl -s https://api.bitbucket.org/2.0/repositories/seanfarley/hg/refs/tags/3.8 -G | jq .
  {
    "name": "3.8",
    "links": {
      "commits": {
        "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commits/3.8"
      },
      "self": {
        "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/refs/tags/3.8"
      },
      "html": {
        "href": "https://bitbucket.org/seanfarley/hg/commits/tag/3.8"
      }
    },
    "tagger": {
      "raw": "Matt Mackall <mpm@selenic.com>",
      "type": "author",
      "user": {
        "username": "mpmselenic",
        "nickname": "mpmselenic",
        "display_name": "Matt Mackall",
        "type": "user",
        "uuid": "{a4934530-db4c-419c-a478-9ab4964c2ee7}",
        "links": {
          "self": {
            "href": "https://api.bitbucket.org/2.0/users/mpmselenic"
          },
          "html": {
            "href": "https://bitbucket.org/mpmselenic/"
          },
          "avatar": {
            "href": "https://bitbucket.org/account/mpmselenic/avatar/32/"
          }
        }
      }
    },
    "date": "2016-05-01T18:52:25+00:00",
    "message": "Added tag 3.8 for changeset f85de28eae32",
    "type": "tag",
    "target": {
      "hash": "f85de28eae32e7d3064b1a1321309071bbaaa069",
      "repository": {
        "links": {
          "self": {
            "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg"
          },
          "html": {
            "href": "https://bitbucket.org/seanfarley/hg"
          },
          "avatar": {
            "href": "https://bitbucket.org/seanfarley/hg/avatar/32/"
          }
        },
        "type": "repository",
        "name": "hg",
        "full_name": "seanfarley/hg",
        "uuid": "{c75687fb-e99d-4579-9087-190dbd406d30}"
      },
      "links": {
        "self": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/f85de28eae32e7d3064b1a1321309071bbaaa069"
        },
        "comments": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/f85de28eae32e7d3064b1a1321309071bbaaa069/comments"
        },
        "patch": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/patch/f85de28eae32e7d3064b1a1321309071bbaaa069"
        },
        "html": {
          "href": "https://bitbucket.org/seanfarley/hg/commits/f85de28eae32e7d3064b1a1321309071bbaaa069"
        },
        "diff": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/diff/f85de28eae32e7d3064b1a1321309071bbaaa069"
        },
        "approve": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/f85de28eae32e7d3064b1a1321309071bbaaa069/approve"
        },
        "statuses": {
          "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/f85de28eae32e7d3064b1a1321309071bbaaa069/statuses"
        }
      },
      "author": {
        "raw": "Sean Farley <sean@farley.io>",
        "type": "author",
        "user": {
          "username": "seanfarley",
          "nickname": "seanfarley",
          "display_name": "Sean Farley",
          "type": "user",
          "uuid": "{a295f8a8-5876-4d43-89b5-3ad8c6c3c51d}",
          "links": {
            "self": {
              "href": "https://api.bitbucket.org/2.0/users/seanfarley"
            },
            "html": {
              "href": "https://bitbucket.org/seanfarley/"
            },
            "avatar": {
              "href": "https://bitbucket.org/account/seanfarley/avatar/32/"
            }
          }
        }
      },
      "parents": [
        {
          "hash": "9a98d0e5b07fc60887f9d3d34d9ac7d536f470d2",
          "type": "commit",
          "links": {
            "self": {
              "href": "https://api.bitbucket.org/2.0/repositories/seanfarley/hg/commit/9a98d0e5b07fc60887f9d3d34d9ac7d536f470d2"
            },
            "html": {
              "href": "https://bitbucket.org/seanfarley/hg/commits/9a98d0e5b07fc60887f9d3d34d9ac7d536f470d2"
            }
          }
        }
      ],
      "date": "2016-05-01T04:21:17+00:00",
      "message": "debian: alphabetize build deps",
      "type": "commit"
    }
  }
  ```
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-tags-name-get
  * @param options Request options.
  */
    async getTag(options) {
        const { headers, errorStrategy, name, repo_slug, workspace } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/refs/tags/${encodeURIComponent(name)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a tag in the specified repository.
  
  The tag name should not include any prefixes (e.g. refs/tags).
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-refs/#api-repositories-workspace-repo-slug-refs-tags-name-delete
  * @param options Request options.
  */
    async deleteTag(options) {
        const { headers, errorStrategy, name, repo_slug, workspace } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/refs/tags/${encodeURIComponent(name)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryEnvironmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Variable = new RepositoryEnvironmentVariableGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Find environments
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-environments-get
     * @param options Request options.
     */
    async getEnvironments(options) {
        const { headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/environments`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create an environment.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-environments-post
     * @param options Request options.
     */
    async createEnvironment(options) {
        const { body, headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/environments`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve an environment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-environments-environment-uuid-get
     * @param options Request options.
     */
    async getEnvironment(options) {
        const { headers, errorStrategy, workspace, repo_slug, environment_uuid } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/environments/${encodeURIComponent(environment_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete an environment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-environments-environment-uuid-delete
     * @param options Request options.
     */
    async deleteEnvironment(options) {
        const { headers, errorStrategy, workspace, repo_slug, environment_uuid } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/environments/${encodeURIComponent(environment_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryEnvironmentVariableGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Find deployment environment level variables.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-deployments-config-environments-environment-uuid-variables-get
     * @param options Request options.
     */
    async getVariables(options) {
        const { headers, errorStrategy, workspace, repo_slug, environment_uuid } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/deployments_config/environments/${encodeURIComponent(environment_uuid)}/variables`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a deployment environment level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-deployments-config-environments-environment-uuid-variables-post
     * @param options Request options.
     */
    async createVariable(options) {
        const { body, headers, errorStrategy, workspace, repo_slug, environment_uuid } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/deployments_config/environments/${encodeURIComponent(environment_uuid)}/variables`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update a deployment environment level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-deployments-config-environments-environment-uuid-variables-variable-uuid-put
     * @param options Request options.
     */
    async updateVariable(options) {
        const { body, headers, errorStrategy, workspace, repo_slug, environment_uuid, variable_uuid } = options;
        const request = new Request("PUT", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/deployments_config/environments/${encodeURIComponent(environment_uuid)}/variables/${encodeURIComponent(variable_uuid)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete a deployment environment level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-repositories-workspace-repo-slug-deployments-config-environments-environment-uuid-variables-variable-uuid-delete
     * @param options Request options.
     */
    async deleteVariable(options) {
        const { headers, errorStrategy, workspace, repo_slug, environment_uuid, variable_uuid } = options;
        const request = new Request("DELETE", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/deployments_config/environments/${encodeURIComponent(environment_uuid)}/variables/${encodeURIComponent(variable_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RepositoryForkGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a paginated list of all the forks of the specified
  repository.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-forks-get
  * @param options Request options.
  */
    async getForks(options) {
        const { headers, errorStrategy, repo_slug, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/forks`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new fork of the specified repository.
  
  #### Forking a repository
  
  To create a fork, specify the workspace explicitly as part of the
  request body:
  
  ```
  $ curl -X POST -u jdoe https://api.bitbucket.org/2.0/repositories/atlassian/bbql/forks \
    -H 'Content-Type: application/json' -d '{
      "name": "bbql_fork",
      "workspace": {
        "slug": "atlassian"
      }
  }'
  ```
  
  To fork a repository into the same workspace, also specify a new `name`.
  
  When you specify a value for `name`, it will also affect the `slug`.
  The `slug` is reflected in the repository URL of the new fork. It is
  derived from `name` by substituting non-ASCII characters, removes
  whitespace, and changes characters to lower case. For example,
  `My repo` would turn into `my_repo`.
  
  You need contributor access to create new forks within a workspace.
  
  
  #### Change the properties of a new fork
  
  By default the fork inherits most of its properties from the parent.
  However, since the optional POST body document follows the normal
  `repository` JSON schema and you can override the new fork's
  properties.
  
  Properties that can be overridden include:
  
  * description
  * fork_policy
  * language
  * mainbranch
  * is_private (note that a private repo's fork_policy might prohibit
    the creation of public forks, in which `is_private=False` would fail)
  * has_issues (to initialize or disable the new repo's issue tracker --
    note that the actual contents of the parent repository's issue
    tracker are not copied during forking)
  * has_wiki (to initialize or disable the new repo's wiki --
    note that the actual contents of the parent repository's wiki are not
    copied during forking)
  * project (when forking into a private project, the fork's `is_private`
    must be `true`)
  
  Properties that cannot be modified include:
  
  * scm
  * parent
  * full_name
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-forks-post
  * @param options Request options.
  */
    async createFork(options) {
        const { body, headers, errorStrategy, repo_slug, workspace } = options;
        const request = new Request("POST", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/forks`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RepositoryDeploymentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Find deployments
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-deployments-get
     * @param options Request options.
     */
    async getDeployments(options) {
        const { headers, errorStrategy, workspace, repo_slug } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/deployments`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a deployment
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-deployments/#api-repositories-workspace-repo-slug-deployments-deployment-uuid-get
     * @param options Request options.
     */
    async getDeployment(options) {
        const { headers, errorStrategy, workspace, repo_slug, deployment_uuid } = options;
        const request = new Request("GET", `/2.0/repositories/${encodeURIComponent(workspace)}/${encodeURIComponent(repo_slug)}/deployments/${encodeURIComponent(deployment_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Permission = new UserPermissionGroup(implementation, this.getGlobalErrorStrategy);
        this.SSH = new UserSSHGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Returns the currently logged in user.
     * Documentation: https://developer.atlassian.com/bitbucket/api/2/reference/resource/user
     * @param options Request options.
     */
    async getCurrentUser(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/2.0/user`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all the authenticated user's email addresses. Both
  confirmed and unconfirmed.
  * Documentation: https://developer.atlassian.com/bitbucket/api/2/reference/resource/user/emails
  * @param options Request options.
  */
    async getCurrentUserEmails(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/2.0/user/emails`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Gets the public information associated with a user account.
  
  If the user's profile is private, `location`, `website` and
  `created_on` elements are omitted.
  
  Note that the user object returned by this operation is changing significantly, due to privacy changes.
  See the [announcement](https://developer.atlassian.com/cloud/bitbucket/bitbucket-api-changes-gdpr/#changes-to-bitbucket-user-objects) for details.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-users/#api-users-selected-user-get
  * @param options Request options.
  */
    async getUser(options) {
        const { headers, errorStrategy, selected_user } = options;
        const request = new Request("GET", `/2.0/users/${encodeURIComponent(selected_user)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns details about a specific one of the authenticated user's
  email addresses.
  
  Details describe whether the address has been confirmed by the user and
  whether it is the user's primary address or not.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-users/#api-user-emails-email-get
  * @param options Request options.
  */
    async getCurrentUserEmail(options) {
        const { headers, errorStrategy, email } = options;
        const request = new Request("GET", `/2.0/user/emails/${encodeURIComponent(email)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserPermissionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns an object for each repository the caller has explicit access
  to and their effective permission — the highest level of permission the
  caller has. This does not return public repositories that the user was
  not granted any specific permission in, and does not distinguish between
  explicit and implicit privileges.
  
  Permissions can be:
  
  * `admin`
  * `write`
  * `read`
  
  Results may be further [filtered or sorted](/cloud/bitbucket/rest/intro/#filtering) by
  repository or permission by adding the following query string
  parameters:
  
  * `q=repository.name="geordi"` or `q=permission>"read"`
  * `sort=repository.name`
  
  Note that the query parameter values need to be URL escaped so that `=`
  would become `%3D`.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-repositories/#api-user-permissions-repositories-get
  * @param options Request options.
  */
    async getCurrentUserRepositoryPermissions(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/2.0/user/permissions/repositories`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns an object for each workspace the caller is a member of, and
  their effective role - the highest level of privilege the caller has.
  If a user is a member of multiple groups with distinct roles, only the
  highest level is returned.
  
  Permissions can be:
  
  * `owner`
  * `collaborator`
  * `member`
  
  **The `collaborator` role is being removed from the Bitbucket Cloud API. For more information,
  see the [deprecation announcement](/cloud/bitbucket/deprecation-notice-collaborator-role/).**
  
  **When you move your administration from Bitbucket Cloud to admin.atlassian.com, the following fields on
  `workspace_membership` will no longer be present: `last_accessed` and `added_on`. See the
  [deprecation announcement](/cloud/bitbucket/announcement-breaking-change-workspace-membership/).**
  
  Results may be further [filtered or sorted](/cloud/bitbucket/rest/intro/#filtering) by
  workspace or permission by adding the following query string parameters:
  
  * `q=workspace.slug="bbworkspace1"` or `q=permission="owner"`
  * `sort=workspace.slug`
  
  Note that the query parameter values need to be URL escaped so that `=`
  would become `%3D`.
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-workspaces/#api-user-permissions-workspaces-get
  * @param options Request options.
  */
    async getCurrentUserWorkspaceMemberships(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/2.0/user/permissions/workspaces`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserSSHGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns a paginated list of the user's SSH public keys.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-get
     * @param options Request options.
     */
    async getKeys(options) {
        const { headers, errorStrategy, selected_user } = options;
        const request = new Request("GET", `/2.0/users/${encodeURIComponent(selected_user)}/ssh-keys`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a new SSH public key to the specified user account and returns the resulting key.
  
  Example:
  
  ```
  $ curl -X POST -H "Content-Type: application/json" -d '{"key": "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKqP3Cr632C2dNhhgKVcon4ldUSAeKiku2yP9O9/bDtY user@myhost"}' https://api.bitbucket.org/2.0/users/{ed08f5e1-605b-4f4a-aee4-6c97628a673e}/ssh-keys
  ```
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-post
  * @param options Request options.
  */
    async addKey(options) {
        const { body, headers, errorStrategy, selected_user } = options;
        const request = new Request("POST", `/2.0/users/${encodeURIComponent(selected_user)}/ssh-keys`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a specific SSH public key belonging to a user.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-key-id-get
     * @param options Request options.
     */
    async getKey(options) {
        const { headers, errorStrategy, key_id, selected_user } = options;
        const request = new Request("GET", `/2.0/users/${encodeURIComponent(selected_user)}/ssh-keys/${encodeURIComponent(key_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a specific SSH public key on a user's account
  
  Note: Only the 'comment' field can be updated using this API. To modify the key or comment values, you must delete and add the key again.
  
  Example:
  
  ```
  $ curl -X PUT -H "Content-Type: application/json" -d '{"label": "Work key"}' https://api.bitbucket.org/2.0/users/{ed08f5e1-605b-4f4a-aee4-6c97628a673e}/ssh-keys/{b15b6026-9c02-4626-b4ad-b905f99f763a}
  ```
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-key-id-put
  * @param options Request options.
  */
    async updateKey(options) {
        const { body, headers, errorStrategy, key_id, selected_user } = options;
        const request = new Request("PUT", `/2.0/users/${encodeURIComponent(selected_user)}/ssh-keys/${encodeURIComponent(key_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes a specific SSH public key from a user's account.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-ssh/#api-users-selected-user-ssh-keys-key-id-delete
     * @param options Request options.
     */
    async deleteKey(options) {
        const { headers, errorStrategy, key_id, selected_user } = options;
        const request = new Request("DELETE", `/2.0/users/${encodeURIComponent(selected_user)}/ssh-keys/${encodeURIComponent(key_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class WorkspaceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Project = new WorkspaceProjectGroup(implementation, this.getGlobalErrorStrategy);
        this.Variable = new WorkspaceVariableGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a list of workspaces accessible by the authenticated user.
  
  Results may be further [filtered or sorted](/cloud/bitbucket/rest/intro/#filtering) by
  workspace or permission by adding the following query string parameters:
  
  * `q=slug="bbworkspace1"` or `q=is_private=true`
  * `sort=created_on`
  
  Note that the query parameter values need to be URL escaped so that `=`
  would become `%3D`.
  
  **The `collaborator` role is being removed from the Bitbucket Cloud API. For more information,
  see the [deprecation announcement](/cloud/bitbucket/deprecation-notice-collaborator-role/).**
  * Documentation: https://developer.atlassian.com/bitbucket/api/2/reference/resource/workspaces
  * @param options Request options.
  */
    async getWorkspaces(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/2.0/workspaces`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the requested workspace.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-workspaces/#api-workspaces-workspace-get
     * @param options Request options.
     */
    async getWorkspace(options) {
        const { headers, errorStrategy, workspace } = options;
        const request = new Request("GET", `/2.0/workspaces/${encodeURIComponent(workspace)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WorkspaceProjectGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Search = new WorkspaceProjectSearchGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Returns the list of projects in this workspace.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-workspaces/#api-workspaces-workspace-projects-get
     * @param options Request options.
     */
    async getProjects(options) {
        const { headers, errorStrategy, workspace } = options;
        const request = new Request("GET", `/2.0/workspaces/${encodeURIComponent(workspace)}/projects`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new project.
  
  Note that the avatar has to be embedded as either a data-url
  or a URL to an external image as shown in the examples below:
  
  ```
  $ body=$(cat << EOF
  {
      "name": "Mars Project",
      "key": "MARS",
      "description": "Software for colonizing mars.",
      "links": {
          "avatar": {
              "href": "data:image/gif;base64,R0lGODlhEAAQAMQAAORHHOVSKudfOulrSOp3WOyDZu6QdvCchPGolfO0o/..."
          }
      },
      "is_private": false
  }
  EOF
  )
  $ curl -H "Content-Type: application/json" \
         -X POST \
         -d "$body" \
         https://api.bitbucket.org/2.0/workspaces/teams-in-space/projects/ | jq .
  {
    // Serialized project document
  }
  ```
  
  or even:
  
  ```
  $ body=$(cat << EOF
  {
      "name": "Mars Project",
      "key": "MARS",
      "description": "Software for colonizing mars.",
      "links": {
          "avatar": {
              "href": "http://i.imgur.com/72tRx4w.gif"
          }
      },
      "is_private": false
  }
  EOF
  )
  $ curl -H "Content-Type: application/json" \
         -X POST \
         -d "$body" \
         https://api.bitbucket.org/2.0/workspaces/teams-in-space/projects/ | jq .
  {
    // Serialized project document
  }
  ```
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-projects/#api-workspaces-workspace-projects-post
  * @param options Request options.
  */
    async createProject(options) {
        const { headers, errorStrategy, workspace } = options;
        const request = new Request("POST", `/2.0/workspaces/${encodeURIComponent(workspace)}/projects`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes this project. This is an irreversible operation.
  
  You cannot delete a project that still contains repositories.
  To delete the project, [delete](/cloud/bitbucket/rest/api-group-repositories/#api-repositories-workspace-repo-slug-delete)
  or transfer the repositories first.
  
  Example:
  ```
  $ curl -X DELETE https://api.bitbucket.org/2.0/workspaces/bbworkspace1/projects/PROJ
  ```
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-projects/#api-workspaces-workspace-projects-project-key-delete
  * @param options Request options.
  */
    async deleteProject(options) {
        const { headers, errorStrategy, project_key, workspace } = options;
        const request = new Request("DELETE", `/2.0/workspaces/${encodeURIComponent(workspace)}/projects/${encodeURIComponent(project_key)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Returns the requested project.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-projects/#api-workspaces-workspace-projects-project-key-get
     * @param options Request options.
     */
    async getProject(options) {
        const { headers, errorStrategy, project_key, workspace } = options;
        const request = new Request("GET", `/2.0/workspaces/${encodeURIComponent(workspace)}/projects/${encodeURIComponent(project_key)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WorkspaceProjectSearchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Search for code in the repositories of the specified workspace.
  
  Note that searches can match in the file's text (`content_matches`),
  the path (`path_matches`), or both.
  
  You can use the same syntax for the search query as in the UI.
  E.g. to search for "foo" only within the repository "demo",
  use the query parameter `search_query=foo+repo:demo`.
  
  Similar to other APIs, you can request more fields using a
  `fields` query parameter. E.g. to get some more information about
  the repository of matched files, use the query parameter
  `search_query=foo&fields=%2Bvalues.file.commit.repository`
  (the `%2B` is a URL-encoded `+`).
  
  Try `fields=%2Bvalues.*.*.*.*` to get an idea what's possible.
    
  * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-other-operations/#api-workspaces-workspace-search-code-get
  * @param options Request options.
  */
    async searchCodeInProjects(options) {
        const { headers, errorStrategy, workspace, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/2.0/workspaces/${encodeURIComponent(workspace)}/search/code`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WorkspaceVariableGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Find workspace level variables.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-get
     * @param options Request options.
     */
    async getVariables(options) {
        const { headers, errorStrategy, workspace } = options;
        const request = new Request("GET", `/2.0/workspaces/${encodeURIComponent(workspace)}/pipelines-config/variables`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a workspace level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-post
     * @param options Request options.
     */
    async createVariable(options) {
        const { body, headers, errorStrategy, workspace } = options;
        const request = new Request("POST", `/2.0/workspaces/${encodeURIComponent(workspace)}/pipelines-config/variables`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a workspace level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-variable-uuid-get
     * @param options Request options.
     */
    async getVariable(options) {
        const { headers, errorStrategy, workspace, variable_uuid } = options;
        const request = new Request("GET", `/2.0/workspaces/${encodeURIComponent(workspace)}/pipelines-config/variables/${encodeURIComponent(variable_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update a workspace level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-variable-uuid-put
     * @param options Request options.
     */
    async updateVariable(options) {
        const { body, headers, errorStrategy, workspace, variable_uuid } = options;
        const request = new Request("PUT", `/2.0/workspaces/${encodeURIComponent(workspace)}/pipelines-config/variables/${encodeURIComponent(variable_uuid)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete a workspace level variable.
     * Documentation: https://developer.atlassian.com/cloud/bitbucket/rest/api-group-pipelines/#api-workspaces-workspace-pipelines-config-variables-variable-uuid-delete
     * @param options Request options.
     */
    async deleteVariable(options) {
        const { headers, errorStrategy, workspace, variable_uuid } = options;
        const request = new Request("DELETE", `/2.0/workspaces/${encodeURIComponent(workspace)}/pipelines-config/variables/${encodeURIComponent(variable_uuid)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
//# sourceMappingURL=index.js.map